searchData={"items":[{"type":"module","title":"Dagger","doc":"The [Dagger](https://dagger.io/) SDK for Elixir.","ref":"Dagger.html"},{"type":"module","title":"Prerequisite - Dagger","doc":"The SDK depends on `docker` and `dagger` commands, please make sure those\ncommands are presents on your `PATH`.","ref":"Dagger.html#module-prerequisite"},{"type":"module","title":"Getting Started - Dagger","doc":"Let's try this script below\n\n    Mix.install([:dagger])\n\n    # 1\n    Application.ensure_all_started(:inets)\n\n    # 2\n    {:ok, client} = Dagger.connect()\n\n    # 3\n    {:ok, output} =\n      client\n      |> Dagger.Client.container()\n      |> Dagger.Container.from(\"hexpm/elixir:1.14.4-erlang-25.3-debian-buster-20230227-slim\")\n      |> Dagger.Container.with_exec([\"elixir\", \"--version\"])\n      |> Dagger.Container.stdout()\n\n    IO.puts(output)\n\n    # 4\n    Dagger.close(client)\n\nHere's what script do:\n\n1. Start `:inets` application in order to use `:httpc` as a HTTP client.\n2. Connecting to the Dagger Engine with `Dagger.connect/1`.\n3. Create a new container from `hexpm/elixir:1.14.4-erlang-25.3-debian-buster-20230227-slim`\n   and calling a command `elixir` with flag `--version`, get the standard\n   output from latest command and printing it to standard output.\n4. Close the connection.","ref":"Dagger.html#module-getting-started"},{"type":"module","title":"Accessing GraphQL API - Dagger","doc":"In case you want to execute GraphQL directly, the SDK provides `Dagger.Core.Client`,\nthe client interface to the Dagger engine. The module provides 2 APIs for you:\n\n1. `Dagger.Core.Client.query/2` - to execute a GraphQL query to the Dagger engine.\n2. `Dagger.Core.Client.execute/2` - to execute a GraphQL query that produces by `Dagger.Core.QueryBuilder`.\n\nBy default, every object types (`Dagger.Container`, `Dagger.Directory`, etc.) has\na field `client` which is an instance of `Dagger.Core.Client`, you can use that instance\nfrom the object type without initialize connection by yourself.\n\nPlease note that this API is an internal API, it may break from version to version. So\nplease use with cautions.","ref":"Dagger.html#module-accessing-graphql-api"},{"type":"module","title":"Module support - Dagger","doc":"The SDK also support Dagger Module, please see `Dagger.Mod.Object` for more\ndetails.","ref":"Dagger.html#module-module-support"},{"type":"function","title":"Dagger.close/1","doc":"Disconnecting the client from Dagger Engine session.","ref":"Dagger.html#close/1"},{"type":"function","title":"Dagger.connect/1","doc":"Connecting to Dagger.\n\nWhen calling this function, it try to connect in order:\n\n1. Use session from `DAGGER_SESSION_PORT` and `DAGGER_SESSION_TOKEN` shell\n   environment variables.\n2. If (1) doesn't specified, it will lookup a binary defined in `_EXPERIMENTAL_DAGGER_CLI_BIN`\n   and start a session.\n3. Download the latest binary from Dagger and start a session.","ref":"Dagger.html#connect/1"},{"type":"function","title":"Options - Dagger.connect/1","doc":"* `:workdir` (`t:String.t/0`) - Sets the engine workdir.\n\n* `:log_output` - The log device to write the progress. The default value is `:stderr`.\n\n* `:connect_timeout` (`t:timeout/0`) - Sets timeout when connect to the engine. The default value is `10000`.\n\n* `:query_timeout` (`t:timeout/0`) - Sets timeout when executing a query. The default value is `:infinity`.","ref":"Dagger.html#connect/1-options"},{"type":"function","title":"Dagger.connect!/1","doc":"Similar to `connect/1` but raise exception when found an error.","ref":"Dagger.html#connect!/1"},{"type":"function","title":"Dagger.with_connection/2","doc":"Connect to Dagger Engine and close connection automatically after `fun` executed.\n\nSee `connect/1` for available options.","ref":"Dagger.html#with_connection/2"},{"type":"module","title":"Dagger.BuildArg","doc":"Key value object that represents a build argument.","ref":"Dagger.BuildArg.html"},{"type":"type","title":"Dagger.BuildArg.t/0","doc":"","ref":"Dagger.BuildArg.html#t:t/0"},{"type":"module","title":"Dagger.CacheSharingMode","doc":"Sharing mode of the cache volume.","ref":"Dagger.CacheSharingMode.html"},{"type":"function","title":"Dagger.CacheSharingMode.locked/0","doc":"Shares the cache volume amongst many build pipelines, but will serialize the writes","ref":"Dagger.CacheSharingMode.html#locked/0"},{"type":"function","title":"Dagger.CacheSharingMode.private/0","doc":"Keeps a cache volume for a single build pipeline","ref":"Dagger.CacheSharingMode.html#private/0"},{"type":"function","title":"Dagger.CacheSharingMode.shared/0","doc":"Shares the cache volume amongst many build pipelines","ref":"Dagger.CacheSharingMode.html#shared/0"},{"type":"type","title":"Dagger.CacheSharingMode.t/0","doc":"","ref":"Dagger.CacheSharingMode.html#t:t/0"},{"type":"module","title":"Dagger.CacheVolume","doc":"A directory whose contents persist across runs.","ref":"Dagger.CacheVolume.html"},{"type":"function","title":"Dagger.CacheVolume.id/1","doc":"A unique identifier for this CacheVolume.","ref":"Dagger.CacheVolume.html#id/1"},{"type":"type","title":"Dagger.CacheVolume.t/0","doc":"","ref":"Dagger.CacheVolume.html#t:t/0"},{"type":"module","title":"Dagger.CacheVolumeID","doc":"The `CacheVolumeID` scalar type represents an identifier for an object of type CacheVolume.","ref":"Dagger.CacheVolumeID.html"},{"type":"type","title":"Dagger.CacheVolumeID.t/0","doc":"","ref":"Dagger.CacheVolumeID.html#t:t/0"},{"type":"module","title":"Dagger.Client","doc":"The root of the DAG.","ref":"Dagger.Client.html"},{"type":"function","title":"Dagger.Client.builtin_container/2","doc":"Retrieves a container builtin to the engine.","ref":"Dagger.Client.html#builtin_container/2"},{"type":"function","title":"Dagger.Client.cache_volume/3","doc":"Constructs a cache volume for a given cache key.","ref":"Dagger.Client.html#cache_volume/3"},{"type":"function","title":"Dagger.Client.container/2","doc":"Creates a scratch container.\n\nOptional platform argument initializes new containers to execute and publish as that platform. Platform defaults to that of the builder's host.","ref":"Dagger.Client.html#container/2"},{"type":"function","title":"Dagger.Client.current_function_call/1","doc":"The FunctionCall context that the SDK caller is currently executing in.\n\nIf the caller is not currently executing in a function, this will return an error.","ref":"Dagger.Client.html#current_function_call/1"},{"type":"function","title":"Dagger.Client.current_module/1","doc":"The module currently being served in the session, if any.","ref":"Dagger.Client.html#current_module/1"},{"type":"function","title":"Dagger.Client.current_type_defs/1","doc":"The TypeDef representations of the objects currently being served in the session.","ref":"Dagger.Client.html#current_type_defs/1"},{"type":"function","title":"Dagger.Client.default_platform/1","doc":"The default platform of the engine.","ref":"Dagger.Client.html#default_platform/1"},{"type":"function","title":"Dagger.Client.directory/1","doc":"Creates an empty directory.","ref":"Dagger.Client.html#directory/1"},{"type":"function","title":"Dagger.Client.engine/1","doc":"The Dagger engine container configuration and state","ref":"Dagger.Client.html#engine/1"},{"type":"function","title":"Dagger.Client.error/2","doc":"Create a new error.","ref":"Dagger.Client.html#error/2"},{"type":"function","title":"Dagger.Client.function/3","doc":"Creates a function.","ref":"Dagger.Client.html#function/3"},{"type":"function","title":"Dagger.Client.generated_code/2","doc":"Create a code generation result, given a directory containing the generated code.","ref":"Dagger.Client.html#generated_code/2"},{"type":"function","title":"Dagger.Client.git/3","doc":"Queries a Git repository.","ref":"Dagger.Client.html#git/3"},{"type":"function","title":"Dagger.Client.host/1","doc":"Queries the host environment.","ref":"Dagger.Client.html#host/1"},{"type":"function","title":"Dagger.Client.http/3","doc":"Returns a file containing an http remote url content.","ref":"Dagger.Client.html#http/3"},{"type":"function","title":"Dagger.Client.llm/2","doc":"Initialize a Large Language Model (LLM)","ref":"Dagger.Client.html#llm/2"},{"type":"function","title":"Dagger.Client.load_cache_volume_from_id/2","doc":"Load a CacheVolume from its ID.","ref":"Dagger.Client.html#load_cache_volume_from_id/2"},{"type":"function","title":"Dagger.Client.load_container_from_id/2","doc":"Load a Container from its ID.","ref":"Dagger.Client.html#load_container_from_id/2"},{"type":"function","title":"Dagger.Client.load_current_module_from_id/2","doc":"Load a CurrentModule from its ID.","ref":"Dagger.Client.html#load_current_module_from_id/2"},{"type":"function","title":"Dagger.Client.load_directory_from_id/2","doc":"Load a Directory from its ID.","ref":"Dagger.Client.html#load_directory_from_id/2"},{"type":"function","title":"Dagger.Client.load_engine_cache_entry_from_id/2","doc":"Load a EngineCacheEntry from its ID.","ref":"Dagger.Client.html#load_engine_cache_entry_from_id/2"},{"type":"function","title":"Dagger.Client.load_engine_cache_entry_set_from_id/2","doc":"Load a EngineCacheEntrySet from its ID.","ref":"Dagger.Client.html#load_engine_cache_entry_set_from_id/2"},{"type":"function","title":"Dagger.Client.load_engine_cache_from_id/2","doc":"Load a EngineCache from its ID.","ref":"Dagger.Client.html#load_engine_cache_from_id/2"},{"type":"function","title":"Dagger.Client.load_engine_from_id/2","doc":"Load a Engine from its ID.","ref":"Dagger.Client.html#load_engine_from_id/2"},{"type":"function","title":"Dagger.Client.load_enum_type_def_from_id/2","doc":"Load a EnumTypeDef from its ID.","ref":"Dagger.Client.html#load_enum_type_def_from_id/2"},{"type":"function","title":"Dagger.Client.load_enum_value_type_def_from_id/2","doc":"Load a EnumValueTypeDef from its ID.","ref":"Dagger.Client.html#load_enum_value_type_def_from_id/2"},{"type":"function","title":"Dagger.Client.load_env_variable_from_id/2","doc":"Load a EnvVariable from its ID.","ref":"Dagger.Client.html#load_env_variable_from_id/2"},{"type":"function","title":"Dagger.Client.load_error_from_id/2","doc":"Load a Error from its ID.","ref":"Dagger.Client.html#load_error_from_id/2"},{"type":"function","title":"Dagger.Client.load_error_value_from_id/2","doc":"Load a ErrorValue from its ID.","ref":"Dagger.Client.html#load_error_value_from_id/2"},{"type":"function","title":"Dagger.Client.load_field_type_def_from_id/2","doc":"Load a FieldTypeDef from its ID.","ref":"Dagger.Client.html#load_field_type_def_from_id/2"},{"type":"function","title":"Dagger.Client.load_file_from_id/2","doc":"Load a File from its ID.","ref":"Dagger.Client.html#load_file_from_id/2"},{"type":"function","title":"Dagger.Client.load_function_arg_from_id/2","doc":"Load a FunctionArg from its ID.","ref":"Dagger.Client.html#load_function_arg_from_id/2"},{"type":"function","title":"Dagger.Client.load_function_call_arg_value_from_id/2","doc":"Load a FunctionCallArgValue from its ID.","ref":"Dagger.Client.html#load_function_call_arg_value_from_id/2"},{"type":"function","title":"Dagger.Client.load_function_call_from_id/2","doc":"Load a FunctionCall from its ID.","ref":"Dagger.Client.html#load_function_call_from_id/2"},{"type":"function","title":"Dagger.Client.load_function_from_id/2","doc":"Load a Function from its ID.","ref":"Dagger.Client.html#load_function_from_id/2"},{"type":"function","title":"Dagger.Client.load_generated_code_from_id/2","doc":"Load a GeneratedCode from its ID.","ref":"Dagger.Client.html#load_generated_code_from_id/2"},{"type":"function","title":"Dagger.Client.load_git_ref_from_id/2","doc":"Load a GitRef from its ID.","ref":"Dagger.Client.html#load_git_ref_from_id/2"},{"type":"function","title":"Dagger.Client.load_git_repository_from_id/2","doc":"Load a GitRepository from its ID.","ref":"Dagger.Client.html#load_git_repository_from_id/2"},{"type":"function","title":"Dagger.Client.load_host_from_id/2","doc":"Load a Host from its ID.","ref":"Dagger.Client.html#load_host_from_id/2"},{"type":"function","title":"Dagger.Client.load_input_type_def_from_id/2","doc":"Load a InputTypeDef from its ID.","ref":"Dagger.Client.html#load_input_type_def_from_id/2"},{"type":"function","title":"Dagger.Client.load_interface_type_def_from_id/2","doc":"Load a InterfaceTypeDef from its ID.","ref":"Dagger.Client.html#load_interface_type_def_from_id/2"},{"type":"function","title":"Dagger.Client.load_label_from_id/2","doc":"Load a Label from its ID.","ref":"Dagger.Client.html#load_label_from_id/2"},{"type":"function","title":"Dagger.Client.load_list_type_def_from_id/2","doc":"Load a ListTypeDef from its ID.","ref":"Dagger.Client.html#load_list_type_def_from_id/2"},{"type":"function","title":"Dagger.Client.load_llm_from_id/2","doc":"Load a LLM from its ID.","ref":"Dagger.Client.html#load_llm_from_id/2"},{"type":"function","title":"Dagger.Client.load_llm_variable_from_id/2","doc":"Load a LLMVariable from its ID.","ref":"Dagger.Client.html#load_llm_variable_from_id/2"},{"type":"function","title":"Dagger.Client.load_module_config_client_from_id/2","doc":"Load a ModuleConfigClient from its ID.","ref":"Dagger.Client.html#load_module_config_client_from_id/2"},{"type":"function","title":"Dagger.Client.load_module_from_id/2","doc":"Load a Module from its ID.","ref":"Dagger.Client.html#load_module_from_id/2"},{"type":"function","title":"Dagger.Client.load_module_source_from_id/2","doc":"Load a ModuleSource from its ID.","ref":"Dagger.Client.html#load_module_source_from_id/2"},{"type":"function","title":"Dagger.Client.load_object_type_def_from_id/2","doc":"Load a ObjectTypeDef from its ID.","ref":"Dagger.Client.html#load_object_type_def_from_id/2"},{"type":"function","title":"Dagger.Client.load_port_from_id/2","doc":"Load a Port from its ID.","ref":"Dagger.Client.html#load_port_from_id/2"},{"type":"function","title":"Dagger.Client.load_scalar_type_def_from_id/2","doc":"Load a ScalarTypeDef from its ID.","ref":"Dagger.Client.html#load_scalar_type_def_from_id/2"},{"type":"function","title":"Dagger.Client.load_sdk_config_from_id/2","doc":"Load a SDKConfig from its ID.","ref":"Dagger.Client.html#load_sdk_config_from_id/2"},{"type":"function","title":"Dagger.Client.load_secret_from_id/2","doc":"Load a Secret from its ID.","ref":"Dagger.Client.html#load_secret_from_id/2"},{"type":"function","title":"Dagger.Client.load_secret_from_name/3","doc":"Load a Secret from its Name.","ref":"Dagger.Client.html#load_secret_from_name/3"},{"type":"function","title":"Dagger.Client.load_service_from_id/2","doc":"Load a Service from its ID.","ref":"Dagger.Client.html#load_service_from_id/2"},{"type":"function","title":"Dagger.Client.load_socket_from_id/2","doc":"Load a Socket from its ID.","ref":"Dagger.Client.html#load_socket_from_id/2"},{"type":"function","title":"Dagger.Client.load_source_map_from_id/2","doc":"Load a SourceMap from its ID.","ref":"Dagger.Client.html#load_source_map_from_id/2"},{"type":"function","title":"Dagger.Client.load_terminal_from_id/2","doc":"Load a Terminal from its ID.","ref":"Dagger.Client.html#load_terminal_from_id/2"},{"type":"function","title":"Dagger.Client.load_type_def_from_id/2","doc":"Load a TypeDef from its ID.","ref":"Dagger.Client.html#load_type_def_from_id/2"},{"type":"function","title":"Dagger.Client.module/1","doc":"Create a new module.","ref":"Dagger.Client.html#module/1"},{"type":"function","title":"Dagger.Client.module_source/3","doc":"Create a new module source instance from a source ref string","ref":"Dagger.Client.html#module_source/3"},{"type":"function","title":"Dagger.Client.secret/2","doc":"Creates a new secret.","ref":"Dagger.Client.html#secret/2"},{"type":"function","title":"Dagger.Client.set_secret/3","doc":"Sets a secret given a user defined name to its plaintext and returns the secret.\n\nThe plaintext value is limited to a size of 128000 bytes.","ref":"Dagger.Client.html#set_secret/3"},{"type":"function","title":"Dagger.Client.source_map/4","doc":"Creates source map metadata.","ref":"Dagger.Client.html#source_map/4"},{"type":"type","title":"Dagger.Client.t/0","doc":"","ref":"Dagger.Client.html#t:t/0"},{"type":"function","title":"Dagger.Client.type_def/1","doc":"Create a new TypeDef.","ref":"Dagger.Client.html#type_def/1"},{"type":"function","title":"Dagger.Client.version/1","doc":"Get the current Dagger Engine version.","ref":"Dagger.Client.html#version/1"},{"type":"module","title":"Dagger.Container","doc":"An OCI-compatible container, also known as a Docker container.","ref":"Dagger.Container.html"},{"type":"function","title":"Dagger.Container.as_service/2","doc":"Turn the container into a Service.\n\nBe sure to set any exposed ports before this conversion.","ref":"Dagger.Container.html#as_service/2"},{"type":"function","title":"Dagger.Container.as_tarball/2","doc":"Returns a File representing the container serialized to a tarball.","ref":"Dagger.Container.html#as_tarball/2"},{"type":"function","title":"Dagger.Container.build/3","doc":"Initializes this container from a Dockerfile build.","ref":"Dagger.Container.html#build/3"},{"type":"function","title":"Dagger.Container.default_args/1","doc":"Retrieves default arguments for future commands.","ref":"Dagger.Container.html#default_args/1"},{"type":"function","title":"Dagger.Container.directory/3","doc":"Retrieves a directory at the given path.\n\nMounts are included.","ref":"Dagger.Container.html#directory/3"},{"type":"function","title":"Dagger.Container.entrypoint/1","doc":"Retrieves entrypoint to be prepended to the arguments of all commands.","ref":"Dagger.Container.html#entrypoint/1"},{"type":"function","title":"Dagger.Container.env_variable/2","doc":"Retrieves the value of the specified environment variable.","ref":"Dagger.Container.html#env_variable/2"},{"type":"function","title":"Dagger.Container.env_variables/1","doc":"Retrieves the list of environment variables passed to commands.","ref":"Dagger.Container.html#env_variables/1"},{"type":"function","title":"Dagger.Container.exit_code/1","doc":"The exit code of the last executed command.\n\nReturns an error if no command was set.","ref":"Dagger.Container.html#exit_code/1"},{"type":"function","title":"Dagger.Container.experimental_with_all_gpus/1","doc":"EXPERIMENTAL API! Subject to change/removal at any time.\n\nConfigures all available GPUs on the host to be accessible to this container.\n\nThis currently works for Nvidia devices only.","ref":"Dagger.Container.html#experimental_with_all_gpus/1"},{"type":"function","title":"Dagger.Container.experimental_with_gpu/2","doc":"EXPERIMENTAL API! Subject to change/removal at any time.\n\nConfigures the provided list of devices to be accessible to this container.\n\nThis currently works for Nvidia devices only.","ref":"Dagger.Container.html#experimental_with_gpu/2"},{"type":"function","title":"Dagger.Container.export/3","doc":"Writes the container as an OCI tarball to the destination file path on the host.\n\nIt can also export platform variants.","ref":"Dagger.Container.html#export/3"},{"type":"function","title":"Dagger.Container.exposed_ports/1","doc":"Retrieves the list of exposed ports.\n\nThis includes ports already exposed by the image, even if not explicitly added with dagger.","ref":"Dagger.Container.html#exposed_ports/1"},{"type":"function","title":"Dagger.Container.file/3","doc":"Retrieves a file at the given path.\n\nMounts are included.","ref":"Dagger.Container.html#file/3"},{"type":"function","title":"Dagger.Container.from/2","doc":"Initializes this container from a pulled base image.","ref":"Dagger.Container.html#from/2"},{"type":"function","title":"Dagger.Container.id/1","doc":"A unique identifier for this Container.","ref":"Dagger.Container.html#id/1"},{"type":"function","title":"Dagger.Container.image_ref/1","doc":"The unique image reference which can only be retrieved immediately after the 'Container.From' call.","ref":"Dagger.Container.html#image_ref/1"},{"type":"function","title":"Dagger.Container.import/3","doc":"Reads the container from an OCI tarball.","ref":"Dagger.Container.html#import/3"},{"type":"function","title":"Dagger.Container.label/2","doc":"Retrieves the value of the specified label.","ref":"Dagger.Container.html#label/2"},{"type":"function","title":"Dagger.Container.labels/1","doc":"Retrieves the list of labels passed to container.","ref":"Dagger.Container.html#labels/1"},{"type":"function","title":"Dagger.Container.mounts/1","doc":"Retrieves the list of paths where a directory is mounted.","ref":"Dagger.Container.html#mounts/1"},{"type":"function","title":"Dagger.Container.platform/1","doc":"The platform this container executes and publishes as.","ref":"Dagger.Container.html#platform/1"},{"type":"function","title":"Dagger.Container.publish/3","doc":"Publishes this container as a new image to the specified address.\n\nPublish returns a fully qualified ref.\n\nIt can also publish platform variants.","ref":"Dagger.Container.html#publish/3"},{"type":"function","title":"Dagger.Container.rootfs/1","doc":"Retrieves this container's root filesystem. Mounts are not included.","ref":"Dagger.Container.html#rootfs/1"},{"type":"function","title":"Dagger.Container.stderr/1","doc":"The error stream of the last executed command.\n\nReturns an error if no command was set.","ref":"Dagger.Container.html#stderr/1"},{"type":"function","title":"Dagger.Container.stdout/1","doc":"The output stream of the last executed command.\n\nReturns an error if no command was set.","ref":"Dagger.Container.html#stdout/1"},{"type":"function","title":"Dagger.Container.sync/1","doc":"Forces evaluation of the pipeline in the engine.\n\nIt doesn't run the default command if no exec has been set.","ref":"Dagger.Container.html#sync/1"},{"type":"type","title":"Dagger.Container.t/0","doc":"","ref":"Dagger.Container.html#t:t/0"},{"type":"function","title":"Dagger.Container.terminal/2","doc":"Opens an interactive terminal for this container using its configured default terminal command if not overridden by args (or sh as a fallback default).","ref":"Dagger.Container.html#terminal/2"},{"type":"function","title":"Dagger.Container.up/2","doc":"Starts a Service and creates a tunnel that forwards traffic from the caller's network to that service.\n\nBe sure to set any exposed ports before calling this api.","ref":"Dagger.Container.html#up/2"},{"type":"function","title":"Dagger.Container.user/1","doc":"Retrieves the user to be set for all commands.","ref":"Dagger.Container.html#user/1"},{"type":"function","title":"Dagger.Container.with_annotation/3","doc":"Retrieves this container plus the given OCI anotation.","ref":"Dagger.Container.html#with_annotation/3"},{"type":"function","title":"Dagger.Container.with_default_args/2","doc":"Configures default arguments for future commands.","ref":"Dagger.Container.html#with_default_args/2"},{"type":"function","title":"Dagger.Container.with_default_terminal_cmd/3","doc":"Set the default command to invoke for the container's terminal API.","ref":"Dagger.Container.html#with_default_terminal_cmd/3"},{"type":"function","title":"Dagger.Container.with_directory/4","doc":"Retrieves this container plus a directory written at the given path.","ref":"Dagger.Container.html#with_directory/4"},{"type":"function","title":"Dagger.Container.with_entrypoint/3","doc":"Retrieves this container but with a different command entrypoint.","ref":"Dagger.Container.html#with_entrypoint/3"},{"type":"function","title":"Dagger.Container.with_env_variable/4","doc":"Retrieves this container plus the given environment variable.","ref":"Dagger.Container.html#with_env_variable/4"},{"type":"function","title":"Dagger.Container.with_exec/3","doc":"Retrieves this container after executing the specified command inside it.","ref":"Dagger.Container.html#with_exec/3"},{"type":"function","title":"Dagger.Container.with_exposed_port/3","doc":"Expose a network port.\n\nExposed ports serve two purposes:\n\n- For health checks and introspection, when running services\n\n- For setting the EXPOSE OCI field when publishing the container","ref":"Dagger.Container.html#with_exposed_port/3"},{"type":"function","title":"Dagger.Container.with_file/4","doc":"Retrieves this container plus the contents of the given file copied to the given path.","ref":"Dagger.Container.html#with_file/4"},{"type":"function","title":"Dagger.Container.with_files/4","doc":"Retrieves this container plus the contents of the given files copied to the given path.","ref":"Dagger.Container.html#with_files/4"},{"type":"function","title":"Dagger.Container.with_label/3","doc":"Retrieves this container plus the given label.","ref":"Dagger.Container.html#with_label/3"},{"type":"function","title":"Dagger.Container.with_mounted_cache/4","doc":"Retrieves this container plus a cache volume mounted at the given path.","ref":"Dagger.Container.html#with_mounted_cache/4"},{"type":"function","title":"Dagger.Container.with_mounted_directory/4","doc":"Retrieves this container plus a directory mounted at the given path.","ref":"Dagger.Container.html#with_mounted_directory/4"},{"type":"function","title":"Dagger.Container.with_mounted_file/4","doc":"Retrieves this container plus a file mounted at the given path.","ref":"Dagger.Container.html#with_mounted_file/4"},{"type":"function","title":"Dagger.Container.with_mounted_secret/4","doc":"Retrieves this container plus a secret mounted into a file at the given path.","ref":"Dagger.Container.html#with_mounted_secret/4"},{"type":"function","title":"Dagger.Container.with_mounted_temp/3","doc":"Retrieves this container plus a temporary directory mounted at the given path. Any writes will be ephemeral to a single withExec call; they will not be persisted to subsequent withExecs.","ref":"Dagger.Container.html#with_mounted_temp/3"},{"type":"function","title":"Dagger.Container.with_new_file/4","doc":"Retrieves this container plus a new file written at the given path.","ref":"Dagger.Container.html#with_new_file/4"},{"type":"function","title":"Dagger.Container.with_registry_auth/4","doc":"Retrieves this container with a registry authentication for a given address.","ref":"Dagger.Container.html#with_registry_auth/4"},{"type":"function","title":"Dagger.Container.with_rootfs/2","doc":"Retrieves the container with the given directory mounted to /.","ref":"Dagger.Container.html#with_rootfs/2"},{"type":"function","title":"Dagger.Container.with_secret_variable/3","doc":"Retrieves this container plus an env variable containing the given secret.","ref":"Dagger.Container.html#with_secret_variable/3"},{"type":"function","title":"Dagger.Container.with_service_binding/3","doc":"Establish a runtime dependency on a service.\n\nThe service will be started automatically when needed and detached when it is no longer needed, executing the default command if none is set.\n\nThe service will be reachable from the container via the provided hostname alias.\n\nThe service dependency will also convey to any files or directories produced by the container.","ref":"Dagger.Container.html#with_service_binding/3"},{"type":"function","title":"Dagger.Container.with_unix_socket/4","doc":"Retrieves this container plus a socket forwarded to the given Unix socket path.","ref":"Dagger.Container.html#with_unix_socket/4"},{"type":"function","title":"Dagger.Container.with_user/2","doc":"Retrieves this container with a different command user.","ref":"Dagger.Container.html#with_user/2"},{"type":"function","title":"Dagger.Container.with_workdir/3","doc":"Retrieves this container with a different working directory.","ref":"Dagger.Container.html#with_workdir/3"},{"type":"function","title":"Dagger.Container.without_annotation/2","doc":"Retrieves this container minus the given OCI annotation.","ref":"Dagger.Container.html#without_annotation/2"},{"type":"function","title":"Dagger.Container.without_default_args/1","doc":"Retrieves this container with unset default arguments for future commands.","ref":"Dagger.Container.html#without_default_args/1"},{"type":"function","title":"Dagger.Container.without_directory/3","doc":"Retrieves this container with the directory at the given path removed.","ref":"Dagger.Container.html#without_directory/3"},{"type":"function","title":"Dagger.Container.without_entrypoint/2","doc":"Retrieves this container with an unset command entrypoint.","ref":"Dagger.Container.html#without_entrypoint/2"},{"type":"function","title":"Dagger.Container.without_env_variable/2","doc":"Retrieves this container minus the given environment variable.","ref":"Dagger.Container.html#without_env_variable/2"},{"type":"function","title":"Dagger.Container.without_exposed_port/3","doc":"Unexpose a previously exposed port.","ref":"Dagger.Container.html#without_exposed_port/3"},{"type":"function","title":"Dagger.Container.without_file/3","doc":"Retrieves this container with the file at the given path removed.","ref":"Dagger.Container.html#without_file/3"},{"type":"function","title":"Dagger.Container.without_files/3","doc":"Retrieves this container with the files at the given paths removed.","ref":"Dagger.Container.html#without_files/3"},{"type":"function","title":"Dagger.Container.without_label/2","doc":"Retrieves this container minus the given environment label.","ref":"Dagger.Container.html#without_label/2"},{"type":"function","title":"Dagger.Container.without_mount/3","doc":"Retrieves this container after unmounting everything at the given path.","ref":"Dagger.Container.html#without_mount/3"},{"type":"function","title":"Dagger.Container.without_registry_auth/2","doc":"Retrieves this container without the registry authentication of a given address.","ref":"Dagger.Container.html#without_registry_auth/2"},{"type":"function","title":"Dagger.Container.without_secret_variable/2","doc":"Retrieves this container minus the given environment variable containing the secret.","ref":"Dagger.Container.html#without_secret_variable/2"},{"type":"function","title":"Dagger.Container.without_unix_socket/3","doc":"Retrieves this container with a previously added Unix socket removed.","ref":"Dagger.Container.html#without_unix_socket/3"},{"type":"function","title":"Dagger.Container.without_user/1","doc":"Retrieves this container with an unset command user.\n\nShould default to root.","ref":"Dagger.Container.html#without_user/1"},{"type":"function","title":"Dagger.Container.without_workdir/1","doc":"Retrieves this container with an unset working directory.\n\nShould default to \"/\".","ref":"Dagger.Container.html#without_workdir/1"},{"type":"function","title":"Dagger.Container.workdir/1","doc":"Retrieves the working directory for all commands.","ref":"Dagger.Container.html#workdir/1"},{"type":"module","title":"Dagger.ContainerID","doc":"The `ContainerID` scalar type represents an identifier for an object of type Container.","ref":"Dagger.ContainerID.html"},{"type":"type","title":"Dagger.ContainerID.t/0","doc":"","ref":"Dagger.ContainerID.html#t:t/0"},{"type":"module","title":"Dagger.Core.Client","doc":"GraphQL client for Dagger.","ref":"Dagger.Core.Client.html"},{"type":"function","title":"Dagger.Core.Client.execute/2","doc":"Send the `query_builder` to the Dagger and get the result from leaf node of\nthe query.","ref":"Dagger.Core.Client.html#execute/2"},{"type":"function","title":"Dagger.Core.Client.query/2","doc":"Send the raw GraphQL query to the Dagger.\n\nReturns a raw response from the Dagger.","ref":"Dagger.Core.Client.html#query/2"},{"type":"module","title":"Dagger.Core.GraphQL.Response","doc":"GraphQL Response type.","ref":"Dagger.Core.GraphQL.Response.html"},{"type":"function","title":"Dagger.Core.GraphQL.Response.from_map/1","doc":"Serialize response from map to struct.","ref":"Dagger.Core.GraphQL.Response.html#from_map/1"},{"type":"module","title":"Dagger.Core.GraphQLClient.Httpc","doc":"`:httpc` HTTP adapter for GraphQL client.","ref":"Dagger.Core.GraphQLClient.Httpc.html"},{"type":"function","title":"Dagger.Core.GraphQLClient.Httpc.request/4","doc":"","ref":"Dagger.Core.GraphQLClient.Httpc.html#request/4"},{"type":"module","title":"Dagger.CurrentModule","doc":"Reflective module API provided to functions at runtime.","ref":"Dagger.CurrentModule.html"},{"type":"function","title":"Dagger.CurrentModule.id/1","doc":"A unique identifier for this CurrentModule.","ref":"Dagger.CurrentModule.html#id/1"},{"type":"function","title":"Dagger.CurrentModule.name/1","doc":"The name of the module being executed in","ref":"Dagger.CurrentModule.html#name/1"},{"type":"function","title":"Dagger.CurrentModule.source/1","doc":"The directory containing the module's source code loaded into the engine (plus any generated code that may have been created).","ref":"Dagger.CurrentModule.html#source/1"},{"type":"type","title":"Dagger.CurrentModule.t/0","doc":"","ref":"Dagger.CurrentModule.html#t:t/0"},{"type":"function","title":"Dagger.CurrentModule.workdir/3","doc":"Load a directory from the module's scratch working directory, including any changes that may have been made to it during module function execution.","ref":"Dagger.CurrentModule.html#workdir/3"},{"type":"function","title":"Dagger.CurrentModule.workdir_file/2","doc":"Load a file from the module's scratch working directory, including any changes that may have been made to it during module function execution.Load a file from the module's scratch working directory, including any changes that may have been made to it during module function execution.","ref":"Dagger.CurrentModule.html#workdir_file/2"},{"type":"module","title":"Dagger.CurrentModuleID","doc":"The `CurrentModuleID` scalar type represents an identifier for an object of type CurrentModule.","ref":"Dagger.CurrentModuleID.html"},{"type":"type","title":"Dagger.CurrentModuleID.t/0","doc":"","ref":"Dagger.CurrentModuleID.html#t:t/0"},{"type":"module","title":"Dagger.Directory","doc":"A directory.","ref":"Dagger.Directory.html"},{"type":"function","title":"Dagger.Directory.as_git/1","doc":"Converts this directory into a git repository","ref":"Dagger.Directory.html#as_git/1"},{"type":"function","title":"Dagger.Directory.as_module/2","doc":"Load the directory as a Dagger module source","ref":"Dagger.Directory.html#as_module/2"},{"type":"function","title":"Dagger.Directory.as_module_source/2","doc":"Load the directory as a Dagger module source","ref":"Dagger.Directory.html#as_module_source/2"},{"type":"function","title":"Dagger.Directory.diff/2","doc":"Gets the difference between this directory and an another directory.","ref":"Dagger.Directory.html#diff/2"},{"type":"function","title":"Dagger.Directory.digest/1","doc":"Return the directory's digest. The format of the digest is not guaranteed to be stable between releases of Dagger. It is guaranteed to be stable between invocations of the same Dagger engine.","ref":"Dagger.Directory.html#digest/1"},{"type":"function","title":"Dagger.Directory.directory/2","doc":"Retrieves a directory at the given path.","ref":"Dagger.Directory.html#directory/2"},{"type":"function","title":"Dagger.Directory.docker_build/2","doc":"Builds a new Docker container from this directory.","ref":"Dagger.Directory.html#docker_build/2"},{"type":"function","title":"Dagger.Directory.entries/2","doc":"Returns a list of files and directories at the given path.","ref":"Dagger.Directory.html#entries/2"},{"type":"function","title":"Dagger.Directory.export/3","doc":"Writes the contents of the directory to a path on the host.","ref":"Dagger.Directory.html#export/3"},{"type":"function","title":"Dagger.Directory.file/2","doc":"Retrieves a file at the given path.","ref":"Dagger.Directory.html#file/2"},{"type":"function","title":"Dagger.Directory.glob/2","doc":"Returns a list of files and directories that matche the given pattern.","ref":"Dagger.Directory.html#glob/2"},{"type":"function","title":"Dagger.Directory.id/1","doc":"A unique identifier for this Directory.","ref":"Dagger.Directory.html#id/1"},{"type":"function","title":"Dagger.Directory.name/1","doc":"Returns the name of the directory.","ref":"Dagger.Directory.html#name/1"},{"type":"function","title":"Dagger.Directory.sync/1","doc":"Force evaluation in the engine.","ref":"Dagger.Directory.html#sync/1"},{"type":"type","title":"Dagger.Directory.t/0","doc":"","ref":"Dagger.Directory.html#t:t/0"},{"type":"function","title":"Dagger.Directory.terminal/2","doc":"Opens an interactive terminal in new container with this directory mounted inside.","ref":"Dagger.Directory.html#terminal/2"},{"type":"function","title":"Dagger.Directory.with_directory/4","doc":"Retrieves this directory plus a directory written at the given path.","ref":"Dagger.Directory.html#with_directory/4"},{"type":"function","title":"Dagger.Directory.with_file/4","doc":"Retrieves this directory plus the contents of the given file copied to the given path.","ref":"Dagger.Directory.html#with_file/4"},{"type":"function","title":"Dagger.Directory.with_files/4","doc":"Retrieves this directory plus the contents of the given files copied to the given path.","ref":"Dagger.Directory.html#with_files/4"},{"type":"function","title":"Dagger.Directory.with_new_directory/3","doc":"Retrieves this directory plus a new directory created at the given path.","ref":"Dagger.Directory.html#with_new_directory/3"},{"type":"function","title":"Dagger.Directory.with_new_file/4","doc":"Retrieves this directory plus a new file written at the given path.","ref":"Dagger.Directory.html#with_new_file/4"},{"type":"function","title":"Dagger.Directory.with_timestamps/2","doc":"Retrieves this directory with all file/dir timestamps set to the given time.","ref":"Dagger.Directory.html#with_timestamps/2"},{"type":"function","title":"Dagger.Directory.without_directory/2","doc":"Retrieves this directory with the directory at the given path removed.","ref":"Dagger.Directory.html#without_directory/2"},{"type":"function","title":"Dagger.Directory.without_file/2","doc":"Retrieves this directory with the file at the given path removed.","ref":"Dagger.Directory.html#without_file/2"},{"type":"function","title":"Dagger.Directory.without_files/2","doc":"Retrieves this directory with the files at the given paths removed.","ref":"Dagger.Directory.html#without_files/2"},{"type":"module","title":"Dagger.DirectoryID","doc":"The `DirectoryID` scalar type represents an identifier for an object of type Directory.","ref":"Dagger.DirectoryID.html"},{"type":"type","title":"Dagger.DirectoryID.t/0","doc":"","ref":"Dagger.DirectoryID.html#t:t/0"},{"type":"module","title":"Dagger.Engine","doc":"The Dagger engine configuration and state","ref":"Dagger.Engine.html"},{"type":"function","title":"Dagger.Engine.id/1","doc":"A unique identifier for this Engine.","ref":"Dagger.Engine.html#id/1"},{"type":"function","title":"Dagger.Engine.local_cache/1","doc":"The local (on-disk) cache for the Dagger engine","ref":"Dagger.Engine.html#local_cache/1"},{"type":"type","title":"Dagger.Engine.t/0","doc":"","ref":"Dagger.Engine.html#t:t/0"},{"type":"module","title":"Dagger.EngineCache","doc":"A cache storage for the Dagger engine","ref":"Dagger.EngineCache.html"},{"type":"function","title":"Dagger.EngineCache.entry_set/2","doc":"The current set of entries in the cache","ref":"Dagger.EngineCache.html#entry_set/2"},{"type":"function","title":"Dagger.EngineCache.id/1","doc":"A unique identifier for this EngineCache.","ref":"Dagger.EngineCache.html#id/1"},{"type":"function","title":"Dagger.EngineCache.keep_bytes/1","doc":"The maximum bytes to keep in the cache without pruning, after which automatic pruning may kick in.","ref":"Dagger.EngineCache.html#keep_bytes/1"},{"type":"function","title":"Dagger.EngineCache.max_used_space/1","doc":"The maximum bytes to keep in the cache without pruning.","ref":"Dagger.EngineCache.html#max_used_space/1"},{"type":"function","title":"Dagger.EngineCache.min_free_space/1","doc":"The target amount of free disk space the garbage collector will attempt to leave.","ref":"Dagger.EngineCache.html#min_free_space/1"},{"type":"function","title":"Dagger.EngineCache.prune/1","doc":"Prune the cache of releaseable entries","ref":"Dagger.EngineCache.html#prune/1"},{"type":"function","title":"Dagger.EngineCache.reserved_space/1","doc":"","ref":"Dagger.EngineCache.html#reserved_space/1"},{"type":"type","title":"Dagger.EngineCache.t/0","doc":"","ref":"Dagger.EngineCache.html#t:t/0"},{"type":"module","title":"Dagger.EngineCacheEntry","doc":"An individual cache entry in a cache entry set","ref":"Dagger.EngineCacheEntry.html"},{"type":"function","title":"Dagger.EngineCacheEntry.actively_used/1","doc":"Whether the cache entry is actively being used.","ref":"Dagger.EngineCacheEntry.html#actively_used/1"},{"type":"function","title":"Dagger.EngineCacheEntry.created_time_unix_nano/1","doc":"The time the cache entry was created, in Unix nanoseconds.","ref":"Dagger.EngineCacheEntry.html#created_time_unix_nano/1"},{"type":"function","title":"Dagger.EngineCacheEntry.description/1","doc":"The description of the cache entry.","ref":"Dagger.EngineCacheEntry.html#description/1"},{"type":"function","title":"Dagger.EngineCacheEntry.disk_space_bytes/1","doc":"The disk space used by the cache entry.","ref":"Dagger.EngineCacheEntry.html#disk_space_bytes/1"},{"type":"function","title":"Dagger.EngineCacheEntry.id/1","doc":"A unique identifier for this EngineCacheEntry.","ref":"Dagger.EngineCacheEntry.html#id/1"},{"type":"function","title":"Dagger.EngineCacheEntry.most_recent_use_time_unix_nano/1","doc":"The most recent time the cache entry was used, in Unix nanoseconds.","ref":"Dagger.EngineCacheEntry.html#most_recent_use_time_unix_nano/1"},{"type":"type","title":"Dagger.EngineCacheEntry.t/0","doc":"","ref":"Dagger.EngineCacheEntry.html#t:t/0"},{"type":"module","title":"Dagger.EngineCacheEntryID","doc":"The `EngineCacheEntryID` scalar type represents an identifier for an object of type EngineCacheEntry.","ref":"Dagger.EngineCacheEntryID.html"},{"type":"type","title":"Dagger.EngineCacheEntryID.t/0","doc":"","ref":"Dagger.EngineCacheEntryID.html#t:t/0"},{"type":"module","title":"Dagger.EngineCacheEntrySet","doc":"A set of cache entries returned by a query to a cache","ref":"Dagger.EngineCacheEntrySet.html"},{"type":"function","title":"Dagger.EngineCacheEntrySet.disk_space_bytes/1","doc":"The total disk space used by the cache entries in this set.","ref":"Dagger.EngineCacheEntrySet.html#disk_space_bytes/1"},{"type":"function","title":"Dagger.EngineCacheEntrySet.entries/1","doc":"The list of individual cache entries in the set","ref":"Dagger.EngineCacheEntrySet.html#entries/1"},{"type":"function","title":"Dagger.EngineCacheEntrySet.entry_count/1","doc":"The number of cache entries in this set.","ref":"Dagger.EngineCacheEntrySet.html#entry_count/1"},{"type":"function","title":"Dagger.EngineCacheEntrySet.id/1","doc":"A unique identifier for this EngineCacheEntrySet.","ref":"Dagger.EngineCacheEntrySet.html#id/1"},{"type":"type","title":"Dagger.EngineCacheEntrySet.t/0","doc":"","ref":"Dagger.EngineCacheEntrySet.html#t:t/0"},{"type":"module","title":"Dagger.EngineCacheEntrySetID","doc":"The `EngineCacheEntrySetID` scalar type represents an identifier for an object of type EngineCacheEntrySet.","ref":"Dagger.EngineCacheEntrySetID.html"},{"type":"type","title":"Dagger.EngineCacheEntrySetID.t/0","doc":"","ref":"Dagger.EngineCacheEntrySetID.html#t:t/0"},{"type":"module","title":"Dagger.EngineCacheID","doc":"The `EngineCacheID` scalar type represents an identifier for an object of type EngineCache.","ref":"Dagger.EngineCacheID.html"},{"type":"type","title":"Dagger.EngineCacheID.t/0","doc":"","ref":"Dagger.EngineCacheID.html#t:t/0"},{"type":"module","title":"Dagger.EngineID","doc":"The `EngineID` scalar type represents an identifier for an object of type Engine.","ref":"Dagger.EngineID.html"},{"type":"type","title":"Dagger.EngineID.t/0","doc":"","ref":"Dagger.EngineID.html#t:t/0"},{"type":"module","title":"Dagger.EnumTypeDef","doc":"A definition of a custom enum defined in a Module.","ref":"Dagger.EnumTypeDef.html"},{"type":"function","title":"Dagger.EnumTypeDef.description/1","doc":"A doc string for the enum, if any.","ref":"Dagger.EnumTypeDef.html#description/1"},{"type":"function","title":"Dagger.EnumTypeDef.id/1","doc":"A unique identifier for this EnumTypeDef.","ref":"Dagger.EnumTypeDef.html#id/1"},{"type":"function","title":"Dagger.EnumTypeDef.name/1","doc":"The name of the enum.","ref":"Dagger.EnumTypeDef.html#name/1"},{"type":"function","title":"Dagger.EnumTypeDef.source_map/1","doc":"The location of this enum declaration.","ref":"Dagger.EnumTypeDef.html#source_map/1"},{"type":"function","title":"Dagger.EnumTypeDef.source_module_name/1","doc":"If this EnumTypeDef is associated with a Module, the name of the module. Unset otherwise.","ref":"Dagger.EnumTypeDef.html#source_module_name/1"},{"type":"type","title":"Dagger.EnumTypeDef.t/0","doc":"","ref":"Dagger.EnumTypeDef.html#t:t/0"},{"type":"function","title":"Dagger.EnumTypeDef.values/1","doc":"The values of the enum.","ref":"Dagger.EnumTypeDef.html#values/1"},{"type":"module","title":"Dagger.EnumTypeDefID","doc":"The `EnumTypeDefID` scalar type represents an identifier for an object of type EnumTypeDef.","ref":"Dagger.EnumTypeDefID.html"},{"type":"type","title":"Dagger.EnumTypeDefID.t/0","doc":"","ref":"Dagger.EnumTypeDefID.html#t:t/0"},{"type":"module","title":"Dagger.EnumValueTypeDef","doc":"A definition of a value in a custom enum defined in a Module.","ref":"Dagger.EnumValueTypeDef.html"},{"type":"function","title":"Dagger.EnumValueTypeDef.description/1","doc":"A doc string for the enum value, if any.","ref":"Dagger.EnumValueTypeDef.html#description/1"},{"type":"function","title":"Dagger.EnumValueTypeDef.id/1","doc":"A unique identifier for this EnumValueTypeDef.","ref":"Dagger.EnumValueTypeDef.html#id/1"},{"type":"function","title":"Dagger.EnumValueTypeDef.name/1","doc":"The name of the enum value.","ref":"Dagger.EnumValueTypeDef.html#name/1"},{"type":"function","title":"Dagger.EnumValueTypeDef.source_map/1","doc":"The location of this enum value declaration.","ref":"Dagger.EnumValueTypeDef.html#source_map/1"},{"type":"type","title":"Dagger.EnumValueTypeDef.t/0","doc":"","ref":"Dagger.EnumValueTypeDef.html#t:t/0"},{"type":"module","title":"Dagger.EnumValueTypeDefID","doc":"The `EnumValueTypeDefID` scalar type represents an identifier for an object of type EnumValueTypeDef.","ref":"Dagger.EnumValueTypeDefID.html"},{"type":"type","title":"Dagger.EnumValueTypeDefID.t/0","doc":"","ref":"Dagger.EnumValueTypeDefID.html#t:t/0"},{"type":"module","title":"Dagger.EnvVariable","doc":"An environment variable name and value.","ref":"Dagger.EnvVariable.html"},{"type":"function","title":"Dagger.EnvVariable.id/1","doc":"A unique identifier for this EnvVariable.","ref":"Dagger.EnvVariable.html#id/1"},{"type":"function","title":"Dagger.EnvVariable.name/1","doc":"The environment variable name.","ref":"Dagger.EnvVariable.html#name/1"},{"type":"type","title":"Dagger.EnvVariable.t/0","doc":"","ref":"Dagger.EnvVariable.html#t:t/0"},{"type":"function","title":"Dagger.EnvVariable.value/1","doc":"The environment variable value.","ref":"Dagger.EnvVariable.html#value/1"},{"type":"module","title":"Dagger.EnvVariableID","doc":"The `EnvVariableID` scalar type represents an identifier for an object of type EnvVariable.","ref":"Dagger.EnvVariableID.html"},{"type":"type","title":"Dagger.EnvVariableID.t/0","doc":"","ref":"Dagger.EnvVariableID.html#t:t/0"},{"type":"module","title":"Dagger.Error","doc":"Dagger.Error","ref":"Dagger.Error.html"},{"type":"function","title":"Dagger.Error.id/1","doc":"A unique identifier for this Error.","ref":"Dagger.Error.html#id/1"},{"type":"function","title":"Dagger.Error.message/1","doc":"A description of the error.","ref":"Dagger.Error.html#message/1"},{"type":"type","title":"Dagger.Error.t/0","doc":"","ref":"Dagger.Error.html#t:t/0"},{"type":"function","title":"Dagger.Error.values/1","doc":"The extensions of the error.","ref":"Dagger.Error.html#values/1"},{"type":"function","title":"Dagger.Error.with_value/3","doc":"Add a value to the error.","ref":"Dagger.Error.html#with_value/3"},{"type":"module","title":"Dagger.ErrorID","doc":"The `ErrorID` scalar type represents an identifier for an object of type Error.","ref":"Dagger.ErrorID.html"},{"type":"type","title":"Dagger.ErrorID.t/0","doc":"","ref":"Dagger.ErrorID.html#t:t/0"},{"type":"module","title":"Dagger.ErrorValue","doc":"Dagger.ErrorValue","ref":"Dagger.ErrorValue.html"},{"type":"function","title":"Dagger.ErrorValue.id/1","doc":"A unique identifier for this ErrorValue.","ref":"Dagger.ErrorValue.html#id/1"},{"type":"function","title":"Dagger.ErrorValue.name/1","doc":"The name of the value.","ref":"Dagger.ErrorValue.html#name/1"},{"type":"type","title":"Dagger.ErrorValue.t/0","doc":"","ref":"Dagger.ErrorValue.html#t:t/0"},{"type":"function","title":"Dagger.ErrorValue.value/1","doc":"The value.","ref":"Dagger.ErrorValue.html#value/1"},{"type":"module","title":"Dagger.ErrorValueID","doc":"The `ErrorValueID` scalar type represents an identifier for an object of type ErrorValue.","ref":"Dagger.ErrorValueID.html"},{"type":"type","title":"Dagger.ErrorValueID.t/0","doc":"","ref":"Dagger.ErrorValueID.html#t:t/0"},{"type":"module","title":"Dagger.FieldTypeDef","doc":"A definition of a field on a custom object defined in a Module.\n\nA field on an object has a static value, as opposed to a function on an object whose value is computed by invoking code (and can accept arguments).","ref":"Dagger.FieldTypeDef.html"},{"type":"function","title":"Dagger.FieldTypeDef.description/1","doc":"A doc string for the field, if any.","ref":"Dagger.FieldTypeDef.html#description/1"},{"type":"function","title":"Dagger.FieldTypeDef.id/1","doc":"A unique identifier for this FieldTypeDef.","ref":"Dagger.FieldTypeDef.html#id/1"},{"type":"function","title":"Dagger.FieldTypeDef.name/1","doc":"The name of the field in lowerCamelCase format.","ref":"Dagger.FieldTypeDef.html#name/1"},{"type":"function","title":"Dagger.FieldTypeDef.source_map/1","doc":"The location of this field declaration.","ref":"Dagger.FieldTypeDef.html#source_map/1"},{"type":"type","title":"Dagger.FieldTypeDef.t/0","doc":"","ref":"Dagger.FieldTypeDef.html#t:t/0"},{"type":"function","title":"Dagger.FieldTypeDef.type_def/1","doc":"The type of the field.","ref":"Dagger.FieldTypeDef.html#type_def/1"},{"type":"module","title":"Dagger.FieldTypeDefID","doc":"The `FieldTypeDefID` scalar type represents an identifier for an object of type FieldTypeDef.","ref":"Dagger.FieldTypeDefID.html"},{"type":"type","title":"Dagger.FieldTypeDefID.t/0","doc":"","ref":"Dagger.FieldTypeDefID.html#t:t/0"},{"type":"module","title":"Dagger.File","doc":"A file.","ref":"Dagger.File.html"},{"type":"function","title":"Dagger.File.contents/1","doc":"Retrieves the contents of the file.","ref":"Dagger.File.html#contents/1"},{"type":"function","title":"Dagger.File.digest/2","doc":"Return the file's digest. The format of the digest is not guaranteed to be stable between releases of Dagger. It is guaranteed to be stable between invocations of the same Dagger engine.","ref":"Dagger.File.html#digest/2"},{"type":"function","title":"Dagger.File.export/3","doc":"Writes the file to a file path on the host.","ref":"Dagger.File.html#export/3"},{"type":"function","title":"Dagger.File.id/1","doc":"A unique identifier for this File.","ref":"Dagger.File.html#id/1"},{"type":"function","title":"Dagger.File.name/1","doc":"Retrieves the name of the file.","ref":"Dagger.File.html#name/1"},{"type":"function","title":"Dagger.File.size/1","doc":"Retrieves the size of the file, in bytes.","ref":"Dagger.File.html#size/1"},{"type":"function","title":"Dagger.File.sync/1","doc":"Force evaluation in the engine.","ref":"Dagger.File.html#sync/1"},{"type":"type","title":"Dagger.File.t/0","doc":"","ref":"Dagger.File.html#t:t/0"},{"type":"function","title":"Dagger.File.with_name/2","doc":"Retrieves this file with its name set to the given name.","ref":"Dagger.File.html#with_name/2"},{"type":"function","title":"Dagger.File.with_timestamps/2","doc":"Retrieves this file with its created/modified timestamps set to the given time.","ref":"Dagger.File.html#with_timestamps/2"},{"type":"module","title":"Dagger.FileID","doc":"The `FileID` scalar type represents an identifier for an object of type File.","ref":"Dagger.FileID.html"},{"type":"type","title":"Dagger.FileID.t/0","doc":"","ref":"Dagger.FileID.html#t:t/0"},{"type":"module","title":"Dagger.Function","doc":"Function represents a resolver provided by a Module.\n\nA function always evaluates against a parent object and is given a set of named arguments.","ref":"Dagger.Function.html"},{"type":"function","title":"Dagger.Function.args/1","doc":"Arguments accepted by the function, if any.","ref":"Dagger.Function.html#args/1"},{"type":"function","title":"Dagger.Function.description/1","doc":"A doc string for the function, if any.","ref":"Dagger.Function.html#description/1"},{"type":"function","title":"Dagger.Function.id/1","doc":"A unique identifier for this Function.","ref":"Dagger.Function.html#id/1"},{"type":"function","title":"Dagger.Function.name/1","doc":"The name of the function.","ref":"Dagger.Function.html#name/1"},{"type":"function","title":"Dagger.Function.return_type/1","doc":"The type returned by the function.","ref":"Dagger.Function.html#return_type/1"},{"type":"function","title":"Dagger.Function.source_map/1","doc":"The location of this function declaration.","ref":"Dagger.Function.html#source_map/1"},{"type":"type","title":"Dagger.Function.t/0","doc":"","ref":"Dagger.Function.html#t:t/0"},{"type":"function","title":"Dagger.Function.with_arg/4","doc":"Returns the function with the provided argument","ref":"Dagger.Function.html#with_arg/4"},{"type":"function","title":"Dagger.Function.with_description/2","doc":"Returns the function with the given doc string.","ref":"Dagger.Function.html#with_description/2"},{"type":"function","title":"Dagger.Function.with_source_map/2","doc":"Returns the function with the given source map.","ref":"Dagger.Function.html#with_source_map/2"},{"type":"module","title":"Dagger.FunctionArg","doc":"An argument accepted by a function.\n\nThis is a specification for an argument at function definition time, not an argument passed at function call time.","ref":"Dagger.FunctionArg.html"},{"type":"function","title":"Dagger.FunctionArg.default_path/1","doc":"Only applies to arguments of type File or Directory. If the argument is not set, load it from the given path in the context directory","ref":"Dagger.FunctionArg.html#default_path/1"},{"type":"function","title":"Dagger.FunctionArg.default_value/1","doc":"A default value to use for this argument when not explicitly set by the caller, if any.","ref":"Dagger.FunctionArg.html#default_value/1"},{"type":"function","title":"Dagger.FunctionArg.description/1","doc":"A doc string for the argument, if any.","ref":"Dagger.FunctionArg.html#description/1"},{"type":"function","title":"Dagger.FunctionArg.id/1","doc":"A unique identifier for this FunctionArg.","ref":"Dagger.FunctionArg.html#id/1"},{"type":"function","title":"Dagger.FunctionArg.ignore/1","doc":"Only applies to arguments of type Directory. The ignore patterns are applied to the input directory, and matching entries are filtered out, in a cache-efficient manner.","ref":"Dagger.FunctionArg.html#ignore/1"},{"type":"function","title":"Dagger.FunctionArg.name/1","doc":"The name of the argument in lowerCamelCase format.","ref":"Dagger.FunctionArg.html#name/1"},{"type":"function","title":"Dagger.FunctionArg.source_map/1","doc":"The location of this arg declaration.","ref":"Dagger.FunctionArg.html#source_map/1"},{"type":"type","title":"Dagger.FunctionArg.t/0","doc":"","ref":"Dagger.FunctionArg.html#t:t/0"},{"type":"function","title":"Dagger.FunctionArg.type_def/1","doc":"The type of the argument.","ref":"Dagger.FunctionArg.html#type_def/1"},{"type":"module","title":"Dagger.FunctionArgID","doc":"The `FunctionArgID` scalar type represents an identifier for an object of type FunctionArg.","ref":"Dagger.FunctionArgID.html"},{"type":"type","title":"Dagger.FunctionArgID.t/0","doc":"","ref":"Dagger.FunctionArgID.html#t:t/0"},{"type":"module","title":"Dagger.FunctionCall","doc":"An active function call.","ref":"Dagger.FunctionCall.html"},{"type":"function","title":"Dagger.FunctionCall.id/1","doc":"A unique identifier for this FunctionCall.","ref":"Dagger.FunctionCall.html#id/1"},{"type":"function","title":"Dagger.FunctionCall.input_args/1","doc":"The argument values the function is being invoked with.","ref":"Dagger.FunctionCall.html#input_args/1"},{"type":"function","title":"Dagger.FunctionCall.name/1","doc":"The name of the function being called.","ref":"Dagger.FunctionCall.html#name/1"},{"type":"function","title":"Dagger.FunctionCall.parent/1","doc":"The value of the parent object of the function being called. If the function is top-level to the module, this is always an empty object.","ref":"Dagger.FunctionCall.html#parent/1"},{"type":"function","title":"Dagger.FunctionCall.parent_name/1","doc":"The name of the parent object of the function being called. If the function is top-level to the module, this is the name of the module.","ref":"Dagger.FunctionCall.html#parent_name/1"},{"type":"function","title":"Dagger.FunctionCall.return_error/2","doc":"Return an error from the function.","ref":"Dagger.FunctionCall.html#return_error/2"},{"type":"function","title":"Dagger.FunctionCall.return_value/2","doc":"Set the return value of the function call to the provided value.","ref":"Dagger.FunctionCall.html#return_value/2"},{"type":"type","title":"Dagger.FunctionCall.t/0","doc":"","ref":"Dagger.FunctionCall.html#t:t/0"},{"type":"module","title":"Dagger.FunctionCallArgValue","doc":"A value passed as a named argument to a function call.","ref":"Dagger.FunctionCallArgValue.html"},{"type":"function","title":"Dagger.FunctionCallArgValue.id/1","doc":"A unique identifier for this FunctionCallArgValue.","ref":"Dagger.FunctionCallArgValue.html#id/1"},{"type":"function","title":"Dagger.FunctionCallArgValue.name/1","doc":"The name of the argument.","ref":"Dagger.FunctionCallArgValue.html#name/1"},{"type":"type","title":"Dagger.FunctionCallArgValue.t/0","doc":"","ref":"Dagger.FunctionCallArgValue.html#t:t/0"},{"type":"function","title":"Dagger.FunctionCallArgValue.value/1","doc":"The value of the argument represented as a JSON serialized string.","ref":"Dagger.FunctionCallArgValue.html#value/1"},{"type":"module","title":"Dagger.FunctionCallArgValueID","doc":"The `FunctionCallArgValueID` scalar type represents an identifier for an object of type FunctionCallArgValue.","ref":"Dagger.FunctionCallArgValueID.html"},{"type":"type","title":"Dagger.FunctionCallArgValueID.t/0","doc":"","ref":"Dagger.FunctionCallArgValueID.html#t:t/0"},{"type":"module","title":"Dagger.FunctionCallID","doc":"The `FunctionCallID` scalar type represents an identifier for an object of type FunctionCall.","ref":"Dagger.FunctionCallID.html"},{"type":"type","title":"Dagger.FunctionCallID.t/0","doc":"","ref":"Dagger.FunctionCallID.html#t:t/0"},{"type":"module","title":"Dagger.FunctionID","doc":"The `FunctionID` scalar type represents an identifier for an object of type Function.","ref":"Dagger.FunctionID.html"},{"type":"type","title":"Dagger.FunctionID.t/0","doc":"","ref":"Dagger.FunctionID.html#t:t/0"},{"type":"module","title":"Dagger.GeneratedCode","doc":"The result of running an SDK's codegen.","ref":"Dagger.GeneratedCode.html"},{"type":"function","title":"Dagger.GeneratedCode.code/1","doc":"The directory containing the generated code.","ref":"Dagger.GeneratedCode.html#code/1"},{"type":"function","title":"Dagger.GeneratedCode.id/1","doc":"A unique identifier for this GeneratedCode.","ref":"Dagger.GeneratedCode.html#id/1"},{"type":"type","title":"Dagger.GeneratedCode.t/0","doc":"","ref":"Dagger.GeneratedCode.html#t:t/0"},{"type":"function","title":"Dagger.GeneratedCode.vcs_generated_paths/1","doc":"List of paths to mark generated in version control (i.e. .gitattributes).","ref":"Dagger.GeneratedCode.html#vcs_generated_paths/1"},{"type":"function","title":"Dagger.GeneratedCode.vcs_ignored_paths/1","doc":"List of paths to ignore in version control (i.e. .gitignore).","ref":"Dagger.GeneratedCode.html#vcs_ignored_paths/1"},{"type":"function","title":"Dagger.GeneratedCode.with_vcs_generated_paths/2","doc":"Set the list of paths to mark generated in version control.","ref":"Dagger.GeneratedCode.html#with_vcs_generated_paths/2"},{"type":"function","title":"Dagger.GeneratedCode.with_vcs_ignored_paths/2","doc":"Set the list of paths to ignore in version control.","ref":"Dagger.GeneratedCode.html#with_vcs_ignored_paths/2"},{"type":"module","title":"Dagger.GeneratedCodeID","doc":"The `GeneratedCodeID` scalar type represents an identifier for an object of type GeneratedCode.","ref":"Dagger.GeneratedCodeID.html"},{"type":"type","title":"Dagger.GeneratedCodeID.t/0","doc":"","ref":"Dagger.GeneratedCodeID.html#t:t/0"},{"type":"module","title":"Dagger.GitRef","doc":"A git ref (tag, branch, or commit).","ref":"Dagger.GitRef.html"},{"type":"function","title":"Dagger.GitRef.commit/1","doc":"The resolved commit id at this ref.","ref":"Dagger.GitRef.html#commit/1"},{"type":"function","title":"Dagger.GitRef.id/1","doc":"A unique identifier for this GitRef.","ref":"Dagger.GitRef.html#id/1"},{"type":"type","title":"Dagger.GitRef.t/0","doc":"","ref":"Dagger.GitRef.html#t:t/0"},{"type":"function","title":"Dagger.GitRef.tree/2","doc":"The filesystem tree at this ref.","ref":"Dagger.GitRef.html#tree/2"},{"type":"module","title":"Dagger.GitRefID","doc":"The `GitRefID` scalar type represents an identifier for an object of type GitRef.","ref":"Dagger.GitRefID.html"},{"type":"type","title":"Dagger.GitRefID.t/0","doc":"","ref":"Dagger.GitRefID.html#t:t/0"},{"type":"module","title":"Dagger.GitRepository","doc":"A git repository.","ref":"Dagger.GitRepository.html"},{"type":"function","title":"Dagger.GitRepository.branch/2","doc":"Returns details of a branch.","ref":"Dagger.GitRepository.html#branch/2"},{"type":"function","title":"Dagger.GitRepository.commit/2","doc":"Returns details of a commit.","ref":"Dagger.GitRepository.html#commit/2"},{"type":"function","title":"Dagger.GitRepository.head/1","doc":"Returns details for HEAD.","ref":"Dagger.GitRepository.html#head/1"},{"type":"function","title":"Dagger.GitRepository.id/1","doc":"A unique identifier for this GitRepository.","ref":"Dagger.GitRepository.html#id/1"},{"type":"function","title":"Dagger.GitRepository.ref/2","doc":"Returns details of a ref.","ref":"Dagger.GitRepository.html#ref/2"},{"type":"type","title":"Dagger.GitRepository.t/0","doc":"","ref":"Dagger.GitRepository.html#t:t/0"},{"type":"function","title":"Dagger.GitRepository.tag/2","doc":"Returns details of a tag.","ref":"Dagger.GitRepository.html#tag/2"},{"type":"function","title":"Dagger.GitRepository.tags/2","doc":"tags that match any of the given glob patterns.","ref":"Dagger.GitRepository.html#tags/2"},{"type":"function","title":"Dagger.GitRepository.with_auth_header/2","doc":"Header to authenticate the remote with.","ref":"Dagger.GitRepository.html#with_auth_header/2"},{"type":"function","title":"Dagger.GitRepository.with_auth_token/2","doc":"Token to authenticate the remote with.","ref":"Dagger.GitRepository.html#with_auth_token/2"},{"type":"module","title":"Dagger.GitRepositoryID","doc":"The `GitRepositoryID` scalar type represents an identifier for an object of type GitRepository.","ref":"Dagger.GitRepositoryID.html"},{"type":"type","title":"Dagger.GitRepositoryID.t/0","doc":"","ref":"Dagger.GitRepositoryID.html#t:t/0"},{"type":"module","title":"Dagger.Host","doc":"Information about the host environment.","ref":"Dagger.Host.html"},{"type":"function","title":"Dagger.Host.directory/3","doc":"Accesses a directory on the host.","ref":"Dagger.Host.html#directory/3"},{"type":"function","title":"Dagger.Host.file/2","doc":"Accesses a file on the host.","ref":"Dagger.Host.html#file/2"},{"type":"function","title":"Dagger.Host.id/1","doc":"A unique identifier for this Host.","ref":"Dagger.Host.html#id/1"},{"type":"function","title":"Dagger.Host.service/3","doc":"Creates a service that forwards traffic to a specified address via the host.","ref":"Dagger.Host.html#service/3"},{"type":"function","title":"Dagger.Host.set_secret_file/3","doc":"Sets a secret given a user-defined name and the file path on the host, and returns the secret.\n\nThe file is limited to a size of 512000 bytes.","ref":"Dagger.Host.html#set_secret_file/3"},{"type":"type","title":"Dagger.Host.t/0","doc":"","ref":"Dagger.Host.html#t:t/0"},{"type":"function","title":"Dagger.Host.tunnel/3","doc":"Creates a tunnel that forwards traffic from the host to a service.","ref":"Dagger.Host.html#tunnel/3"},{"type":"function","title":"Dagger.Host.unix_socket/2","doc":"Accesses a Unix socket on the host.","ref":"Dagger.Host.html#unix_socket/2"},{"type":"module","title":"Dagger.HostID","doc":"The `HostID` scalar type represents an identifier for an object of type Host.","ref":"Dagger.HostID.html"},{"type":"type","title":"Dagger.HostID.t/0","doc":"","ref":"Dagger.HostID.html#t:t/0"},{"type":"module","title":"Dagger.ImageLayerCompression","doc":"Compression algorithm to use for image layers.","ref":"Dagger.ImageLayerCompression.html"},{"type":"function","title":"Dagger.ImageLayerCompression.e_star_gz/0","doc":"","ref":"Dagger.ImageLayerCompression.html#e_star_gz/0"},{"type":"function","title":"Dagger.ImageLayerCompression.gzip/0","doc":"","ref":"Dagger.ImageLayerCompression.html#gzip/0"},{"type":"type","title":"Dagger.ImageLayerCompression.t/0","doc":"","ref":"Dagger.ImageLayerCompression.html#t:t/0"},{"type":"function","title":"Dagger.ImageLayerCompression.uncompressed/0","doc":"","ref":"Dagger.ImageLayerCompression.html#uncompressed/0"},{"type":"function","title":"Dagger.ImageLayerCompression.zstd/0","doc":"","ref":"Dagger.ImageLayerCompression.html#zstd/0"},{"type":"module","title":"Dagger.ImageMediaTypes","doc":"Mediatypes to use in published or exported image metadata.","ref":"Dagger.ImageMediaTypes.html"},{"type":"function","title":"Dagger.ImageMediaTypes.docker_media_types/0","doc":"","ref":"Dagger.ImageMediaTypes.html#docker_media_types/0"},{"type":"function","title":"Dagger.ImageMediaTypes.oci_media_types/0","doc":"","ref":"Dagger.ImageMediaTypes.html#oci_media_types/0"},{"type":"type","title":"Dagger.ImageMediaTypes.t/0","doc":"","ref":"Dagger.ImageMediaTypes.html#t:t/0"},{"type":"module","title":"Dagger.InputTypeDef","doc":"A graphql input type, which is essentially just a group of named args.\nThis is currently only used to represent pre-existing usage of graphql input types\nin the core API. It is not used by user modules and shouldn't ever be as user\nmodule accept input objects via their id rather than graphql input types.","ref":"Dagger.InputTypeDef.html"},{"type":"function","title":"Dagger.InputTypeDef.fields/1","doc":"Static fields defined on this input object, if any.","ref":"Dagger.InputTypeDef.html#fields/1"},{"type":"function","title":"Dagger.InputTypeDef.id/1","doc":"A unique identifier for this InputTypeDef.","ref":"Dagger.InputTypeDef.html#id/1"},{"type":"function","title":"Dagger.InputTypeDef.name/1","doc":"The name of the input object.","ref":"Dagger.InputTypeDef.html#name/1"},{"type":"type","title":"Dagger.InputTypeDef.t/0","doc":"","ref":"Dagger.InputTypeDef.html#t:t/0"},{"type":"module","title":"Dagger.InputTypeDefID","doc":"The `InputTypeDefID` scalar type represents an identifier for an object of type InputTypeDef.","ref":"Dagger.InputTypeDefID.html"},{"type":"type","title":"Dagger.InputTypeDefID.t/0","doc":"","ref":"Dagger.InputTypeDefID.html#t:t/0"},{"type":"module","title":"Dagger.InterfaceTypeDef","doc":"A definition of a custom interface defined in a Module.","ref":"Dagger.InterfaceTypeDef.html"},{"type":"function","title":"Dagger.InterfaceTypeDef.description/1","doc":"The doc string for the interface, if any.","ref":"Dagger.InterfaceTypeDef.html#description/1"},{"type":"function","title":"Dagger.InterfaceTypeDef.functions/1","doc":"Functions defined on this interface, if any.","ref":"Dagger.InterfaceTypeDef.html#functions/1"},{"type":"function","title":"Dagger.InterfaceTypeDef.id/1","doc":"A unique identifier for this InterfaceTypeDef.","ref":"Dagger.InterfaceTypeDef.html#id/1"},{"type":"function","title":"Dagger.InterfaceTypeDef.name/1","doc":"The name of the interface.","ref":"Dagger.InterfaceTypeDef.html#name/1"},{"type":"function","title":"Dagger.InterfaceTypeDef.source_map/1","doc":"The location of this interface declaration.","ref":"Dagger.InterfaceTypeDef.html#source_map/1"},{"type":"function","title":"Dagger.InterfaceTypeDef.source_module_name/1","doc":"If this InterfaceTypeDef is associated with a Module, the name of the module. Unset otherwise.","ref":"Dagger.InterfaceTypeDef.html#source_module_name/1"},{"type":"type","title":"Dagger.InterfaceTypeDef.t/0","doc":"","ref":"Dagger.InterfaceTypeDef.html#t:t/0"},{"type":"module","title":"Dagger.InterfaceTypeDefID","doc":"The `InterfaceTypeDefID` scalar type represents an identifier for an object of type InterfaceTypeDef.","ref":"Dagger.InterfaceTypeDefID.html"},{"type":"type","title":"Dagger.InterfaceTypeDefID.t/0","doc":"","ref":"Dagger.InterfaceTypeDefID.html#t:t/0"},{"type":"module","title":"Dagger.JSON","doc":"An arbitrary JSON-encoded value.","ref":"Dagger.JSON.html"},{"type":"type","title":"Dagger.JSON.t/0","doc":"","ref":"Dagger.JSON.html#t:t/0"},{"type":"module","title":"Dagger.LLM","doc":"Dagger.LLM","ref":"Dagger.LLM.html"},{"type":"function","title":"Dagger.LLM.cache_volume/1","doc":"Retrieve a the current value in the LLM environment, of type CacheVolume","ref":"Dagger.LLM.html#cache_volume/1"},{"type":"function","title":"Dagger.LLM.container/1","doc":"Retrieve a the current value in the LLM environment, of type Container","ref":"Dagger.LLM.html#container/1"},{"type":"function","title":"Dagger.LLM.current_module/1","doc":"Retrieve a the current value in the LLM environment, of type CurrentModule","ref":"Dagger.LLM.html#current_module/1"},{"type":"function","title":"Dagger.LLM.directory/1","doc":"Retrieve a the current value in the LLM environment, of type Directory","ref":"Dagger.LLM.html#directory/1"},{"type":"function","title":"Dagger.LLM.enum_type_def/1","doc":"Retrieve a the current value in the LLM environment, of type EnumTypeDef","ref":"Dagger.LLM.html#enum_type_def/1"},{"type":"function","title":"Dagger.LLM.enum_value_type_def/1","doc":"Retrieve a the current value in the LLM environment, of type EnumValueTypeDef","ref":"Dagger.LLM.html#enum_value_type_def/1"},{"type":"function","title":"Dagger.LLM.error/1","doc":"Retrieve a the current value in the LLM environment, of type Error","ref":"Dagger.LLM.html#error/1"},{"type":"function","title":"Dagger.LLM.error_value/1","doc":"Retrieve a the current value in the LLM environment, of type ErrorValue","ref":"Dagger.LLM.html#error_value/1"},{"type":"function","title":"Dagger.LLM.field_type_def/1","doc":"Retrieve a the current value in the LLM environment, of type FieldTypeDef","ref":"Dagger.LLM.html#field_type_def/1"},{"type":"function","title":"Dagger.LLM.file/1","doc":"Retrieve a the current value in the LLM environment, of type File","ref":"Dagger.LLM.html#file/1"},{"type":"function","title":"Dagger.LLM.function/1","doc":"Retrieve a the current value in the LLM environment, of type Function","ref":"Dagger.LLM.html#function/1"},{"type":"function","title":"Dagger.LLM.function_arg/1","doc":"Retrieve a the current value in the LLM environment, of type FunctionArg","ref":"Dagger.LLM.html#function_arg/1"},{"type":"function","title":"Dagger.LLM.function_call/1","doc":"Retrieve a the current value in the LLM environment, of type FunctionCall","ref":"Dagger.LLM.html#function_call/1"},{"type":"function","title":"Dagger.LLM.function_call_arg_value/1","doc":"Retrieve a the current value in the LLM environment, of type FunctionCallArgValue","ref":"Dagger.LLM.html#function_call_arg_value/1"},{"type":"function","title":"Dagger.LLM.generated_code/1","doc":"Retrieve a the current value in the LLM environment, of type GeneratedCode","ref":"Dagger.LLM.html#generated_code/1"},{"type":"function","title":"Dagger.LLM.get_cache_volume/2","doc":"Retrieve a variable in the llm environment, of type CacheVolume","ref":"Dagger.LLM.html#get_cache_volume/2"},{"type":"function","title":"Dagger.LLM.get_container/2","doc":"Retrieve a variable in the llm environment, of type Container","ref":"Dagger.LLM.html#get_container/2"},{"type":"function","title":"Dagger.LLM.get_current_module/2","doc":"Retrieve a variable in the llm environment, of type CurrentModule","ref":"Dagger.LLM.html#get_current_module/2"},{"type":"function","title":"Dagger.LLM.get_directory/2","doc":"Retrieve a variable in the llm environment, of type Directory","ref":"Dagger.LLM.html#get_directory/2"},{"type":"function","title":"Dagger.LLM.get_enum_type_def/2","doc":"Retrieve a variable in the llm environment, of type EnumTypeDef","ref":"Dagger.LLM.html#get_enum_type_def/2"},{"type":"function","title":"Dagger.LLM.get_enum_value_type_def/2","doc":"Retrieve a variable in the llm environment, of type EnumValueTypeDef","ref":"Dagger.LLM.html#get_enum_value_type_def/2"},{"type":"function","title":"Dagger.LLM.get_error/2","doc":"Retrieve a variable in the llm environment, of type Error","ref":"Dagger.LLM.html#get_error/2"},{"type":"function","title":"Dagger.LLM.get_error_value/2","doc":"Retrieve a variable in the llm environment, of type ErrorValue","ref":"Dagger.LLM.html#get_error_value/2"},{"type":"function","title":"Dagger.LLM.get_field_type_def/2","doc":"Retrieve a variable in the llm environment, of type FieldTypeDef","ref":"Dagger.LLM.html#get_field_type_def/2"},{"type":"function","title":"Dagger.LLM.get_file/2","doc":"Retrieve a variable in the llm environment, of type File","ref":"Dagger.LLM.html#get_file/2"},{"type":"function","title":"Dagger.LLM.get_function/2","doc":"Retrieve a variable in the llm environment, of type Function","ref":"Dagger.LLM.html#get_function/2"},{"type":"function","title":"Dagger.LLM.get_function_arg/2","doc":"Retrieve a variable in the llm environment, of type FunctionArg","ref":"Dagger.LLM.html#get_function_arg/2"},{"type":"function","title":"Dagger.LLM.get_function_call/2","doc":"Retrieve a variable in the llm environment, of type FunctionCall","ref":"Dagger.LLM.html#get_function_call/2"},{"type":"function","title":"Dagger.LLM.get_function_call_arg_value/2","doc":"Retrieve a variable in the llm environment, of type FunctionCallArgValue","ref":"Dagger.LLM.html#get_function_call_arg_value/2"},{"type":"function","title":"Dagger.LLM.get_generated_code/2","doc":"Retrieve a variable in the llm environment, of type GeneratedCode","ref":"Dagger.LLM.html#get_generated_code/2"},{"type":"function","title":"Dagger.LLM.get_git_ref/2","doc":"Retrieve a variable in the llm environment, of type GitRef","ref":"Dagger.LLM.html#get_git_ref/2"},{"type":"function","title":"Dagger.LLM.get_git_repository/2","doc":"Retrieve a variable in the llm environment, of type GitRepository","ref":"Dagger.LLM.html#get_git_repository/2"},{"type":"function","title":"Dagger.LLM.get_input_type_def/2","doc":"Retrieve a variable in the llm environment, of type InputTypeDef","ref":"Dagger.LLM.html#get_input_type_def/2"},{"type":"function","title":"Dagger.LLM.get_interface_type_def/2","doc":"Retrieve a variable in the llm environment, of type InterfaceTypeDef","ref":"Dagger.LLM.html#get_interface_type_def/2"},{"type":"function","title":"Dagger.LLM.get_list_type_def/2","doc":"Retrieve a variable in the llm environment, of type ListTypeDef","ref":"Dagger.LLM.html#get_list_type_def/2"},{"type":"function","title":"Dagger.LLM.get_llm/2","doc":"Retrieve a variable in the llm environment, of type LLM","ref":"Dagger.LLM.html#get_llm/2"},{"type":"function","title":"Dagger.LLM.get_module/2","doc":"Retrieve a variable in the llm environment, of type Module","ref":"Dagger.LLM.html#get_module/2"},{"type":"function","title":"Dagger.LLM.get_module_config_client/2","doc":"Retrieve a variable in the llm environment, of type ModuleConfigClient","ref":"Dagger.LLM.html#get_module_config_client/2"},{"type":"function","title":"Dagger.LLM.get_module_source/2","doc":"Retrieve a variable in the llm environment, of type ModuleSource","ref":"Dagger.LLM.html#get_module_source/2"},{"type":"function","title":"Dagger.LLM.get_object_type_def/2","doc":"Retrieve a variable in the llm environment, of type ObjectTypeDef","ref":"Dagger.LLM.html#get_object_type_def/2"},{"type":"function","title":"Dagger.LLM.get_scalar_type_def/2","doc":"Retrieve a variable in the llm environment, of type ScalarTypeDef","ref":"Dagger.LLM.html#get_scalar_type_def/2"},{"type":"function","title":"Dagger.LLM.get_sdk_config/2","doc":"Retrieve a variable in the llm environment, of type SDKConfig","ref":"Dagger.LLM.html#get_sdk_config/2"},{"type":"function","title":"Dagger.LLM.get_secret/2","doc":"Retrieve a variable in the llm environment, of type Secret","ref":"Dagger.LLM.html#get_secret/2"},{"type":"function","title":"Dagger.LLM.get_service/2","doc":"Retrieve a variable in the llm environment, of type Service","ref":"Dagger.LLM.html#get_service/2"},{"type":"function","title":"Dagger.LLM.get_socket/2","doc":"Retrieve a variable in the llm environment, of type Socket","ref":"Dagger.LLM.html#get_socket/2"},{"type":"function","title":"Dagger.LLM.get_source_map/2","doc":"Retrieve a variable in the llm environment, of type SourceMap","ref":"Dagger.LLM.html#get_source_map/2"},{"type":"function","title":"Dagger.LLM.get_string/2","doc":"Get a string variable from the LLM's environment","ref":"Dagger.LLM.html#get_string/2"},{"type":"function","title":"Dagger.LLM.get_terminal/2","doc":"Retrieve a variable in the llm environment, of type Terminal","ref":"Dagger.LLM.html#get_terminal/2"},{"type":"function","title":"Dagger.LLM.get_type_def/2","doc":"Retrieve a variable in the llm environment, of type TypeDef","ref":"Dagger.LLM.html#get_type_def/2"},{"type":"function","title":"Dagger.LLM.git_ref/1","doc":"Retrieve a the current value in the LLM environment, of type GitRef","ref":"Dagger.LLM.html#git_ref/1"},{"type":"function","title":"Dagger.LLM.git_repository/1","doc":"Retrieve a the current value in the LLM environment, of type GitRepository","ref":"Dagger.LLM.html#git_repository/1"},{"type":"function","title":"Dagger.LLM.history/1","doc":"return the llm message history","ref":"Dagger.LLM.html#history/1"},{"type":"function","title":"Dagger.LLM.history_json/1","doc":"return the raw llm message history as json","ref":"Dagger.LLM.html#history_json/1"},{"type":"function","title":"Dagger.LLM.id/1","doc":"A unique identifier for this LLM.","ref":"Dagger.LLM.html#id/1"},{"type":"function","title":"Dagger.LLM.input_type_def/1","doc":"Retrieve a the current value in the LLM environment, of type InputTypeDef","ref":"Dagger.LLM.html#input_type_def/1"},{"type":"function","title":"Dagger.LLM.interface_type_def/1","doc":"Retrieve a the current value in the LLM environment, of type InterfaceTypeDef","ref":"Dagger.LLM.html#interface_type_def/1"},{"type":"function","title":"Dagger.LLM.l_lm/1","doc":"Retrieve a the current value in the LLM environment, of type LLM","ref":"Dagger.LLM.html#l_lm/1"},{"type":"function","title":"Dagger.LLM.last_reply/1","doc":"return the last llm reply from the history","ref":"Dagger.LLM.html#last_reply/1"},{"type":"function","title":"Dagger.LLM.list_type_def/1","doc":"Retrieve a the current value in the LLM environment, of type ListTypeDef","ref":"Dagger.LLM.html#list_type_def/1"},{"type":"function","title":"Dagger.LLM.loop/1","doc":"synchronize LLM state","ref":"Dagger.LLM.html#loop/1"},{"type":"function","title":"Dagger.LLM.model/1","doc":"return the model used by the llm","ref":"Dagger.LLM.html#model/1"},{"type":"function","title":"Dagger.LLM.module/1","doc":"Retrieve a the current value in the LLM environment, of type Module","ref":"Dagger.LLM.html#module/1"},{"type":"function","title":"Dagger.LLM.module_config_client/1","doc":"Retrieve a the current value in the LLM environment, of type ModuleConfigClient","ref":"Dagger.LLM.html#module_config_client/1"},{"type":"function","title":"Dagger.LLM.module_source/1","doc":"Retrieve a the current value in the LLM environment, of type ModuleSource","ref":"Dagger.LLM.html#module_source/1"},{"type":"function","title":"Dagger.LLM.object_type_def/1","doc":"Retrieve a the current value in the LLM environment, of type ObjectTypeDef","ref":"Dagger.LLM.html#object_type_def/1"},{"type":"function","title":"Dagger.LLM.provider/1","doc":"return the provider used by the llm","ref":"Dagger.LLM.html#provider/1"},{"type":"function","title":"Dagger.LLM.scalar_type_def/1","doc":"Retrieve a the current value in the LLM environment, of type ScalarTypeDef","ref":"Dagger.LLM.html#scalar_type_def/1"},{"type":"function","title":"Dagger.LLM.sdkconfig/1","doc":"Retrieve a the current value in the LLM environment, of type SDKConfig","ref":"Dagger.LLM.html#sdkconfig/1"},{"type":"function","title":"Dagger.LLM.secret/1","doc":"Retrieve a the current value in the LLM environment, of type Secret","ref":"Dagger.LLM.html#secret/1"},{"type":"function","title":"Dagger.LLM.service/1","doc":"Retrieve a the current value in the LLM environment, of type Service","ref":"Dagger.LLM.html#service/1"},{"type":"function","title":"Dagger.LLM.set_cache_volume/3","doc":"Set a variable of type CacheVolume in the llm environment","ref":"Dagger.LLM.html#set_cache_volume/3"},{"type":"function","title":"Dagger.LLM.set_container/3","doc":"Set a variable of type Container in the llm environment","ref":"Dagger.LLM.html#set_container/3"},{"type":"function","title":"Dagger.LLM.set_current_module/3","doc":"Set a variable of type CurrentModule in the llm environment","ref":"Dagger.LLM.html#set_current_module/3"},{"type":"function","title":"Dagger.LLM.set_directory/3","doc":"Set a variable of type Directory in the llm environment","ref":"Dagger.LLM.html#set_directory/3"},{"type":"function","title":"Dagger.LLM.set_enum_type_def/3","doc":"Set a variable of type EnumTypeDef in the llm environment","ref":"Dagger.LLM.html#set_enum_type_def/3"},{"type":"function","title":"Dagger.LLM.set_enum_value_type_def/3","doc":"Set a variable of type EnumValueTypeDef in the llm environment","ref":"Dagger.LLM.html#set_enum_value_type_def/3"},{"type":"function","title":"Dagger.LLM.set_error/3","doc":"Set a variable of type Error in the llm environment","ref":"Dagger.LLM.html#set_error/3"},{"type":"function","title":"Dagger.LLM.set_error_value/3","doc":"Set a variable of type ErrorValue in the llm environment","ref":"Dagger.LLM.html#set_error_value/3"},{"type":"function","title":"Dagger.LLM.set_field_type_def/3","doc":"Set a variable of type FieldTypeDef in the llm environment","ref":"Dagger.LLM.html#set_field_type_def/3"},{"type":"function","title":"Dagger.LLM.set_file/3","doc":"Set a variable of type File in the llm environment","ref":"Dagger.LLM.html#set_file/3"},{"type":"function","title":"Dagger.LLM.set_function/3","doc":"Set a variable of type Function in the llm environment","ref":"Dagger.LLM.html#set_function/3"},{"type":"function","title":"Dagger.LLM.set_function_arg/3","doc":"Set a variable of type FunctionArg in the llm environment","ref":"Dagger.LLM.html#set_function_arg/3"},{"type":"function","title":"Dagger.LLM.set_function_call/3","doc":"Set a variable of type FunctionCall in the llm environment","ref":"Dagger.LLM.html#set_function_call/3"},{"type":"function","title":"Dagger.LLM.set_function_call_arg_value/3","doc":"Set a variable of type FunctionCallArgValue in the llm environment","ref":"Dagger.LLM.html#set_function_call_arg_value/3"},{"type":"function","title":"Dagger.LLM.set_generated_code/3","doc":"Set a variable of type GeneratedCode in the llm environment","ref":"Dagger.LLM.html#set_generated_code/3"},{"type":"function","title":"Dagger.LLM.set_git_ref/3","doc":"Set a variable of type GitRef in the llm environment","ref":"Dagger.LLM.html#set_git_ref/3"},{"type":"function","title":"Dagger.LLM.set_git_repository/3","doc":"Set a variable of type GitRepository in the llm environment","ref":"Dagger.LLM.html#set_git_repository/3"},{"type":"function","title":"Dagger.LLM.set_input_type_def/3","doc":"Set a variable of type InputTypeDef in the llm environment","ref":"Dagger.LLM.html#set_input_type_def/3"},{"type":"function","title":"Dagger.LLM.set_interface_type_def/3","doc":"Set a variable of type InterfaceTypeDef in the llm environment","ref":"Dagger.LLM.html#set_interface_type_def/3"},{"type":"function","title":"Dagger.LLM.set_list_type_def/3","doc":"Set a variable of type ListTypeDef in the llm environment","ref":"Dagger.LLM.html#set_list_type_def/3"},{"type":"function","title":"Dagger.LLM.set_llm/3","doc":"Set a variable of type LLM in the llm environment","ref":"Dagger.LLM.html#set_llm/3"},{"type":"function","title":"Dagger.LLM.set_module/3","doc":"Set a variable of type Module in the llm environment","ref":"Dagger.LLM.html#set_module/3"},{"type":"function","title":"Dagger.LLM.set_module_config_client/3","doc":"Set a variable of type ModuleConfigClient in the llm environment","ref":"Dagger.LLM.html#set_module_config_client/3"},{"type":"function","title":"Dagger.LLM.set_module_source/3","doc":"Set a variable of type ModuleSource in the llm environment","ref":"Dagger.LLM.html#set_module_source/3"},{"type":"function","title":"Dagger.LLM.set_object_type_def/3","doc":"Set a variable of type ObjectTypeDef in the llm environment","ref":"Dagger.LLM.html#set_object_type_def/3"},{"type":"function","title":"Dagger.LLM.set_scalar_type_def/3","doc":"Set a variable of type ScalarTypeDef in the llm environment","ref":"Dagger.LLM.html#set_scalar_type_def/3"},{"type":"function","title":"Dagger.LLM.set_sdk_config/3","doc":"Set a variable of type SDKConfig in the llm environment","ref":"Dagger.LLM.html#set_sdk_config/3"},{"type":"function","title":"Dagger.LLM.set_secret/3","doc":"Set a variable of type Secret in the llm environment","ref":"Dagger.LLM.html#set_secret/3"},{"type":"function","title":"Dagger.LLM.set_service/3","doc":"Set a variable of type Service in the llm environment","ref":"Dagger.LLM.html#set_service/3"},{"type":"function","title":"Dagger.LLM.set_socket/3","doc":"Set a variable of type Socket in the llm environment","ref":"Dagger.LLM.html#set_socket/3"},{"type":"function","title":"Dagger.LLM.set_source_map/3","doc":"Set a variable of type SourceMap in the llm environment","ref":"Dagger.LLM.html#set_source_map/3"},{"type":"function","title":"Dagger.LLM.set_string/3","doc":"Add a string variable to the LLM's environment","ref":"Dagger.LLM.html#set_string/3"},{"type":"function","title":"Dagger.LLM.set_terminal/3","doc":"Set a variable of type Terminal in the llm environment","ref":"Dagger.LLM.html#set_terminal/3"},{"type":"function","title":"Dagger.LLM.set_type_def/3","doc":"Set a variable of type TypeDef in the llm environment","ref":"Dagger.LLM.html#set_type_def/3"},{"type":"function","title":"Dagger.LLM.socket/1","doc":"Retrieve a the current value in the LLM environment, of type Socket","ref":"Dagger.LLM.html#socket/1"},{"type":"function","title":"Dagger.LLM.source_map/1","doc":"Retrieve a the current value in the LLM environment, of type SourceMap","ref":"Dagger.LLM.html#source_map/1"},{"type":"function","title":"Dagger.LLM.sync/1","doc":"synchronize LLM state","ref":"Dagger.LLM.html#sync/1"},{"type":"type","title":"Dagger.LLM.t/0","doc":"","ref":"Dagger.LLM.html#t:t/0"},{"type":"function","title":"Dagger.LLM.terminal/1","doc":"Retrieve a the current value in the LLM environment, of type Terminal","ref":"Dagger.LLM.html#terminal/1"},{"type":"function","title":"Dagger.LLM.tools/1","doc":"print documentation for available tools","ref":"Dagger.LLM.html#tools/1"},{"type":"function","title":"Dagger.LLM.type_def/1","doc":"Retrieve a the current value in the LLM environment, of type TypeDef","ref":"Dagger.LLM.html#type_def/1"},{"type":"function","title":"Dagger.LLM.variables/1","doc":"list variables in the LLM environment","ref":"Dagger.LLM.html#variables/1"},{"type":"function","title":"Dagger.LLM.with_cache_volume/2","doc":"Set a variable of type CacheVolume in the llm environment","ref":"Dagger.LLM.html#with_cache_volume/2"},{"type":"function","title":"Dagger.LLM.with_container/2","doc":"Set a variable of type Container in the llm environment","ref":"Dagger.LLM.html#with_container/2"},{"type":"function","title":"Dagger.LLM.with_current_module/2","doc":"Set a variable of type CurrentModule in the llm environment","ref":"Dagger.LLM.html#with_current_module/2"},{"type":"function","title":"Dagger.LLM.with_directory/2","doc":"Set a variable of type Directory in the llm environment","ref":"Dagger.LLM.html#with_directory/2"},{"type":"function","title":"Dagger.LLM.with_enum_type_def/2","doc":"Set a variable of type EnumTypeDef in the llm environment","ref":"Dagger.LLM.html#with_enum_type_def/2"},{"type":"function","title":"Dagger.LLM.with_enum_value_type_def/2","doc":"Set a variable of type EnumValueTypeDef in the llm environment","ref":"Dagger.LLM.html#with_enum_value_type_def/2"},{"type":"function","title":"Dagger.LLM.with_error/2","doc":"Set a variable of type Error in the llm environment","ref":"Dagger.LLM.html#with_error/2"},{"type":"function","title":"Dagger.LLM.with_error_value/2","doc":"Set a variable of type ErrorValue in the llm environment","ref":"Dagger.LLM.html#with_error_value/2"},{"type":"function","title":"Dagger.LLM.with_field_type_def/2","doc":"Set a variable of type FieldTypeDef in the llm environment","ref":"Dagger.LLM.html#with_field_type_def/2"},{"type":"function","title":"Dagger.LLM.with_file/2","doc":"Set a variable of type File in the llm environment","ref":"Dagger.LLM.html#with_file/2"},{"type":"function","title":"Dagger.LLM.with_function/2","doc":"Set a variable of type Function in the llm environment","ref":"Dagger.LLM.html#with_function/2"},{"type":"function","title":"Dagger.LLM.with_function_arg/2","doc":"Set a variable of type FunctionArg in the llm environment","ref":"Dagger.LLM.html#with_function_arg/2"},{"type":"function","title":"Dagger.LLM.with_function_call/2","doc":"Set a variable of type FunctionCall in the llm environment","ref":"Dagger.LLM.html#with_function_call/2"},{"type":"function","title":"Dagger.LLM.with_function_call_arg_value/2","doc":"Set a variable of type FunctionCallArgValue in the llm environment","ref":"Dagger.LLM.html#with_function_call_arg_value/2"},{"type":"function","title":"Dagger.LLM.with_generated_code/2","doc":"Set a variable of type GeneratedCode in the llm environment","ref":"Dagger.LLM.html#with_generated_code/2"},{"type":"function","title":"Dagger.LLM.with_git_ref/2","doc":"Set a variable of type GitRef in the llm environment","ref":"Dagger.LLM.html#with_git_ref/2"},{"type":"function","title":"Dagger.LLM.with_git_repository/2","doc":"Set a variable of type GitRepository in the llm environment","ref":"Dagger.LLM.html#with_git_repository/2"},{"type":"function","title":"Dagger.LLM.with_input_type_def/2","doc":"Set a variable of type InputTypeDef in the llm environment","ref":"Dagger.LLM.html#with_input_type_def/2"},{"type":"function","title":"Dagger.LLM.with_interface_type_def/2","doc":"Set a variable of type InterfaceTypeDef in the llm environment","ref":"Dagger.LLM.html#with_interface_type_def/2"},{"type":"function","title":"Dagger.LLM.with_list_type_def/2","doc":"Set a variable of type ListTypeDef in the llm environment","ref":"Dagger.LLM.html#with_list_type_def/2"},{"type":"function","title":"Dagger.LLM.with_llm/2","doc":"Set a variable of type LLM in the llm environment","ref":"Dagger.LLM.html#with_llm/2"},{"type":"function","title":"Dagger.LLM.with_model/2","doc":"swap out the llm model","ref":"Dagger.LLM.html#with_model/2"},{"type":"function","title":"Dagger.LLM.with_module/2","doc":"Set a variable of type Module in the llm environment","ref":"Dagger.LLM.html#with_module/2"},{"type":"function","title":"Dagger.LLM.with_module_config_client/2","doc":"Set a variable of type ModuleConfigClient in the llm environment","ref":"Dagger.LLM.html#with_module_config_client/2"},{"type":"function","title":"Dagger.LLM.with_module_source/2","doc":"Set a variable of type ModuleSource in the llm environment","ref":"Dagger.LLM.html#with_module_source/2"},{"type":"function","title":"Dagger.LLM.with_object_type_def/2","doc":"Set a variable of type ObjectTypeDef in the llm environment","ref":"Dagger.LLM.html#with_object_type_def/2"},{"type":"function","title":"Dagger.LLM.with_prompt/2","doc":"append a prompt to the llm context","ref":"Dagger.LLM.html#with_prompt/2"},{"type":"function","title":"Dagger.LLM.with_prompt_file/2","doc":"append the contents of a file to the llm context","ref":"Dagger.LLM.html#with_prompt_file/2"},{"type":"function","title":"Dagger.LLM.with_prompt_var/3","doc":"Add a string variable to the LLM's environment","ref":"Dagger.LLM.html#with_prompt_var/3"},{"type":"function","title":"Dagger.LLM.with_scalar_type_def/2","doc":"Set a variable of type ScalarTypeDef in the llm environment","ref":"Dagger.LLM.html#with_scalar_type_def/2"},{"type":"function","title":"Dagger.LLM.with_sdk_config/2","doc":"Set a variable of type SDKConfig in the llm environment","ref":"Dagger.LLM.html#with_sdk_config/2"},{"type":"function","title":"Dagger.LLM.with_secret/2","doc":"Set a variable of type Secret in the llm environment","ref":"Dagger.LLM.html#with_secret/2"},{"type":"function","title":"Dagger.LLM.with_service/2","doc":"Set a variable of type Service in the llm environment","ref":"Dagger.LLM.html#with_service/2"},{"type":"function","title":"Dagger.LLM.with_socket/2","doc":"Set a variable of type Socket in the llm environment","ref":"Dagger.LLM.html#with_socket/2"},{"type":"function","title":"Dagger.LLM.with_source_map/2","doc":"Set a variable of type SourceMap in the llm environment","ref":"Dagger.LLM.html#with_source_map/2"},{"type":"function","title":"Dagger.LLM.with_terminal/2","doc":"Set a variable of type Terminal in the llm environment","ref":"Dagger.LLM.html#with_terminal/2"},{"type":"function","title":"Dagger.LLM.with_type_def/2","doc":"Set a variable of type TypeDef in the llm environment","ref":"Dagger.LLM.html#with_type_def/2"},{"type":"module","title":"Dagger.LLMID","doc":"The `LLMID` scalar type represents an identifier for an object of type LLM.","ref":"Dagger.LLMID.html"},{"type":"type","title":"Dagger.LLMID.t/0","doc":"","ref":"Dagger.LLMID.html#t:t/0"},{"type":"module","title":"Dagger.LLMVariable","doc":"Dagger.LLMVariable","ref":"Dagger.LLMVariable.html"},{"type":"function","title":"Dagger.LLMVariable.hash/1","doc":"","ref":"Dagger.LLMVariable.html#hash/1"},{"type":"function","title":"Dagger.LLMVariable.id/1","doc":"A unique identifier for this LLMVariable.","ref":"Dagger.LLMVariable.html#id/1"},{"type":"function","title":"Dagger.LLMVariable.name/1","doc":"","ref":"Dagger.LLMVariable.html#name/1"},{"type":"type","title":"Dagger.LLMVariable.t/0","doc":"","ref":"Dagger.LLMVariable.html#t:t/0"},{"type":"function","title":"Dagger.LLMVariable.type_name/1","doc":"","ref":"Dagger.LLMVariable.html#type_name/1"},{"type":"module","title":"Dagger.LLMVariableID","doc":"The `LLMVariableID` scalar type represents an identifier for an object of type LLMVariable.","ref":"Dagger.LLMVariableID.html"},{"type":"type","title":"Dagger.LLMVariableID.t/0","doc":"","ref":"Dagger.LLMVariableID.html#t:t/0"},{"type":"module","title":"Dagger.Label","doc":"A simple key value object that represents a label.","ref":"Dagger.Label.html"},{"type":"function","title":"Dagger.Label.id/1","doc":"A unique identifier for this Label.","ref":"Dagger.Label.html#id/1"},{"type":"function","title":"Dagger.Label.name/1","doc":"The label name.","ref":"Dagger.Label.html#name/1"},{"type":"type","title":"Dagger.Label.t/0","doc":"","ref":"Dagger.Label.html#t:t/0"},{"type":"function","title":"Dagger.Label.value/1","doc":"The label value.","ref":"Dagger.Label.html#value/1"},{"type":"module","title":"Dagger.LabelID","doc":"The `LabelID` scalar type represents an identifier for an object of type Label.","ref":"Dagger.LabelID.html"},{"type":"type","title":"Dagger.LabelID.t/0","doc":"","ref":"Dagger.LabelID.html#t:t/0"},{"type":"module","title":"Dagger.ListTypeDef","doc":"A definition of a list type in a Module.","ref":"Dagger.ListTypeDef.html"},{"type":"function","title":"Dagger.ListTypeDef.element_type_def/1","doc":"The type of the elements in the list.","ref":"Dagger.ListTypeDef.html#element_type_def/1"},{"type":"function","title":"Dagger.ListTypeDef.id/1","doc":"A unique identifier for this ListTypeDef.","ref":"Dagger.ListTypeDef.html#id/1"},{"type":"type","title":"Dagger.ListTypeDef.t/0","doc":"","ref":"Dagger.ListTypeDef.html#t:t/0"},{"type":"module","title":"Dagger.ListTypeDefID","doc":"The `ListTypeDefID` scalar type represents an identifier for an object of type ListTypeDef.","ref":"Dagger.ListTypeDefID.html"},{"type":"type","title":"Dagger.ListTypeDefID.t/0","doc":"","ref":"Dagger.ListTypeDefID.html#t:t/0"},{"type":"module","title":"Dagger.Mod.Decoder","doc":"Provides set of functions for decoding value from function call.","ref":"Dagger.Mod.Decoder.html"},{"type":"function","title":"Dagger.Mod.Decoder.decode/3","doc":"Decode the given `value` into a proper `type`.","ref":"Dagger.Mod.Decoder.html#decode/3"},{"type":"module","title":"Dagger.Mod.Encoder","doc":"Provides set of functions for encoding value from function call.","ref":"Dagger.Mod.Encoder.html"},{"type":"function","title":"Dagger.Mod.Encoder.validate_and_encode/2","doc":"Validate the given `value` and encoding it.","ref":"Dagger.Mod.Encoder.html#validate_and_encode/2"},{"type":"module","title":"Dagger.Mod.Object","doc":"Declare a module as an object type.","ref":"Dagger.Mod.Object.html"},{"type":"module","title":"Declare an object - Dagger.Mod.Object","doc":"Add `use Dagger.Mod.Object` to the Elixir module that want to be a\nDagger module and give a name through `:name` configuration:\n\n    defmodule Potato do\n      use Dagger.Mod.Object, name: \"Potato\"\n\n      # ...\n    end\n\nThe module also support documentation by using Elixir standard documentation,\n`@moduledoc`.","ref":"Dagger.Mod.Object.html#module-declare-an-object"},{"type":"module","title":"Declare a function - Dagger.Mod.Object","doc":"The module provides a `defn`, a macro for declare a function.\nLet's declare a new function named `echo` that accepts a `name` as a string\nand return a container that echo a name in the module `Potato` from the previous\nsection:\n\n    defmodule Potato do\n      use Dagger.Mod.Object, name: \"Potato\"\n\n      defn echo(name: String.t()) :: Dagger.Container.t() do\n        dag()\n        |> Dagger.Client.container()\n        |> Dagger.Container.from(\"alpine\")\n        |> Dagger.Container.with_exec([\"echo\", name])\n      end\n    end\n\nFrom the example above, the `defn` allows you to annotate a type to function\narguments and return type by using Elixir Typespec. The type will convert to\na Dagger type when registering a module.\n\nThe supported primitive types for now are:\n\n1. `integer()` for a boolean type.\n2. `boolean()` for a boolean type.\n3. `String.t()` or `binary()` for a string type.\n4. `list(type)` or `[type]` for a list type.\n5. `type | nil` for optional type.\n6. Any type that generated under `Dagger` namespace (`Dagger.Container.t()`,\n   `Dagger.Directory.t()`, etc.).\n\nThe function also support documentation by using Elixir standard documentation,\n`@doc`.","ref":"Dagger.Mod.Object.html#module-declare-a-function"},{"type":"macro","title":"Dagger.Mod.Object.defn/2","doc":"Declare a function.","ref":"Dagger.Mod.Object.html#defn/2"},{"type":"type","title":"Dagger.Mod.Object.function_def/0","doc":"","ref":"Dagger.Mod.Object.html#t:function_def/0"},{"type":"type","title":"Dagger.Mod.Object.function_name/0","doc":"","ref":"Dagger.Mod.Object.html#t:function_name/0"},{"type":"function","title":"Dagger.Mod.Object.get_function_doc/2","doc":"Get function documentation.\n\nReturn doc string or `nil` if that function didn't have a documentation.","ref":"Dagger.Mod.Object.html#get_function_doc/2"},{"type":"function","title":"Dagger.Mod.Object.get_module_doc/1","doc":"Get module documentation.\n\nReturns module doc string or `nil` if the given module didn't have a documentation.","ref":"Dagger.Mod.Object.html#get_module_doc/1"},{"type":"module","title":"Dagger.Module","doc":"A Dagger module.","ref":"Dagger.Module.html"},{"type":"function","title":"Dagger.Module.dependencies/1","doc":"The dependencies of the module.","ref":"Dagger.Module.html#dependencies/1"},{"type":"function","title":"Dagger.Module.description/1","doc":"The doc string of the module, if any","ref":"Dagger.Module.html#description/1"},{"type":"function","title":"Dagger.Module.enums/1","doc":"Enumerations served by this module.","ref":"Dagger.Module.html#enums/1"},{"type":"function","title":"Dagger.Module.generated_context_directory/1","doc":"The generated files and directories made on top of the module source's context directory.","ref":"Dagger.Module.html#generated_context_directory/1"},{"type":"function","title":"Dagger.Module.id/1","doc":"A unique identifier for this Module.","ref":"Dagger.Module.html#id/1"},{"type":"function","title":"Dagger.Module.interfaces/1","doc":"Interfaces served by this module.","ref":"Dagger.Module.html#interfaces/1"},{"type":"function","title":"Dagger.Module.name/1","doc":"The name of the module","ref":"Dagger.Module.html#name/1"},{"type":"function","title":"Dagger.Module.objects/1","doc":"Objects served by this module.","ref":"Dagger.Module.html#objects/1"},{"type":"function","title":"Dagger.Module.runtime/1","doc":"The container that runs the module's entrypoint. It will fail to execute if the module doesn't compile.","ref":"Dagger.Module.html#runtime/1"},{"type":"function","title":"Dagger.Module.sdk/1","doc":"The SDK config used by this module.","ref":"Dagger.Module.html#sdk/1"},{"type":"function","title":"Dagger.Module.serve/1","doc":"Serve a module's API in the current session.\n\nNote: this can only be called once per session. In the future, it could return a stream or service to remove the side effect.","ref":"Dagger.Module.html#serve/1"},{"type":"function","title":"Dagger.Module.source/1","doc":"The source for the module.","ref":"Dagger.Module.html#source/1"},{"type":"function","title":"Dagger.Module.sync/1","doc":"Forces evaluation of the module, including any loading into the engine and associated validation.","ref":"Dagger.Module.html#sync/1"},{"type":"type","title":"Dagger.Module.t/0","doc":"","ref":"Dagger.Module.html#t:t/0"},{"type":"function","title":"Dagger.Module.with_description/2","doc":"Retrieves the module with the given description","ref":"Dagger.Module.html#with_description/2"},{"type":"function","title":"Dagger.Module.with_enum/2","doc":"This module plus the given Enum type and associated values","ref":"Dagger.Module.html#with_enum/2"},{"type":"function","title":"Dagger.Module.with_interface/2","doc":"This module plus the given Interface type and associated functions","ref":"Dagger.Module.html#with_interface/2"},{"type":"function","title":"Dagger.Module.with_object/2","doc":"This module plus the given Object type and associated functions.","ref":"Dagger.Module.html#with_object/2"},{"type":"module","title":"Dagger.ModuleConfigClient","doc":"The client generated for the module.","ref":"Dagger.ModuleConfigClient.html"},{"type":"function","title":"Dagger.ModuleConfigClient.dev/1","doc":"If true, generate the client in developer mode.","ref":"Dagger.ModuleConfigClient.html#dev/1"},{"type":"function","title":"Dagger.ModuleConfigClient.directory/1","doc":"The directory the client is generated in.","ref":"Dagger.ModuleConfigClient.html#directory/1"},{"type":"function","title":"Dagger.ModuleConfigClient.generator/1","doc":"The generator to use","ref":"Dagger.ModuleConfigClient.html#generator/1"},{"type":"function","title":"Dagger.ModuleConfigClient.id/1","doc":"A unique identifier for this ModuleConfigClient.","ref":"Dagger.ModuleConfigClient.html#id/1"},{"type":"type","title":"Dagger.ModuleConfigClient.t/0","doc":"","ref":"Dagger.ModuleConfigClient.html#t:t/0"},{"type":"module","title":"Dagger.ModuleConfigClientID","doc":"The `ModuleConfigClientID` scalar type represents an identifier for an object of type ModuleConfigClient.","ref":"Dagger.ModuleConfigClientID.html"},{"type":"type","title":"Dagger.ModuleConfigClientID.t/0","doc":"","ref":"Dagger.ModuleConfigClientID.html#t:t/0"},{"type":"module","title":"Dagger.ModuleID","doc":"The `ModuleID` scalar type represents an identifier for an object of type Module.","ref":"Dagger.ModuleID.html"},{"type":"type","title":"Dagger.ModuleID.t/0","doc":"","ref":"Dagger.ModuleID.html#t:t/0"},{"type":"module","title":"Dagger.ModuleSource","doc":"The source needed to load and run a module, along with any metadata about the source such as versions/urls/etc.","ref":"Dagger.ModuleSource.html"},{"type":"function","title":"Dagger.ModuleSource.as_module/1","doc":"Load the source as a module. If this is a local source, the parent directory must have been provided during module source creation","ref":"Dagger.ModuleSource.html#as_module/1"},{"type":"function","title":"Dagger.ModuleSource.as_string/1","doc":"A human readable ref string representation of this module source.","ref":"Dagger.ModuleSource.html#as_string/1"},{"type":"function","title":"Dagger.ModuleSource.clone_ref/1","doc":"The ref to clone the root of the git repo from. Only valid for git sources.","ref":"Dagger.ModuleSource.html#clone_ref/1"},{"type":"function","title":"Dagger.ModuleSource.commit/1","doc":"The resolved commit of the git repo this source points to. Only valid for git sources.","ref":"Dagger.ModuleSource.html#commit/1"},{"type":"function","title":"Dagger.ModuleSource.config_clients/1","doc":"The clients generated for the module.","ref":"Dagger.ModuleSource.html#config_clients/1"},{"type":"function","title":"Dagger.ModuleSource.config_exists/1","doc":"Whether an existing dagger.json for the module was found.","ref":"Dagger.ModuleSource.html#config_exists/1"},{"type":"function","title":"Dagger.ModuleSource.context_directory/1","doc":"The full directory loaded for the module source, including the source code as a subdirectory.","ref":"Dagger.ModuleSource.html#context_directory/1"},{"type":"function","title":"Dagger.ModuleSource.dependencies/1","doc":"The dependencies of the module source.","ref":"Dagger.ModuleSource.html#dependencies/1"},{"type":"function","title":"Dagger.ModuleSource.digest/1","doc":"A content-hash of the module source. Module sources with the same digest will output the same generated context and convert into the same module instance.","ref":"Dagger.ModuleSource.html#digest/1"},{"type":"function","title":"Dagger.ModuleSource.directory/2","doc":"The directory containing the module configuration and source code (source code may be in a subdir).","ref":"Dagger.ModuleSource.html#directory/2"},{"type":"function","title":"Dagger.ModuleSource.engine_version/1","doc":"The engine version of the module.","ref":"Dagger.ModuleSource.html#engine_version/1"},{"type":"function","title":"Dagger.ModuleSource.generated_context_directory/1","doc":"The generated files and directories made on top of the module source's context directory.","ref":"Dagger.ModuleSource.html#generated_context_directory/1"},{"type":"function","title":"Dagger.ModuleSource.html_repo_url/1","doc":"The URL to access the web view of the repository (e.g., GitHub, GitLab, Bitbucket). Only valid for git sources.","ref":"Dagger.ModuleSource.html#html_repo_url/1"},{"type":"function","title":"Dagger.ModuleSource.html_url/1","doc":"The URL to the source's git repo in a web browser. Only valid for git sources.","ref":"Dagger.ModuleSource.html#html_url/1"},{"type":"function","title":"Dagger.ModuleSource.id/1","doc":"A unique identifier for this ModuleSource.","ref":"Dagger.ModuleSource.html#id/1"},{"type":"function","title":"Dagger.ModuleSource.kind/1","doc":"The kind of module source (currently local, git or dir).","ref":"Dagger.ModuleSource.html#kind/1"},{"type":"function","title":"Dagger.ModuleSource.local_context_directory_path/1","doc":"The full absolute path to the context directory on the caller's host filesystem that this module source is loaded from. Only valid for local module sources.","ref":"Dagger.ModuleSource.html#local_context_directory_path/1"},{"type":"function","title":"Dagger.ModuleSource.module_name/1","doc":"The name of the module, including any setting via the withName API.","ref":"Dagger.ModuleSource.html#module_name/1"},{"type":"function","title":"Dagger.ModuleSource.module_original_name/1","doc":"The original name of the module as read from the module's dagger.json (or set for the first time with the withName API).","ref":"Dagger.ModuleSource.html#module_original_name/1"},{"type":"function","title":"Dagger.ModuleSource.original_subpath/1","doc":"The original subpath used when instantiating this module source, relative to the context directory.","ref":"Dagger.ModuleSource.html#original_subpath/1"},{"type":"function","title":"Dagger.ModuleSource.pin/1","doc":"The pinned version of this module source.","ref":"Dagger.ModuleSource.html#pin/1"},{"type":"function","title":"Dagger.ModuleSource.repo_root_path/1","doc":"The import path corresponding to the root of the git repo this source points to. Only valid for git sources.","ref":"Dagger.ModuleSource.html#repo_root_path/1"},{"type":"function","title":"Dagger.ModuleSource.sdk/1","doc":"The SDK configuration of the module.","ref":"Dagger.ModuleSource.html#sdk/1"},{"type":"function","title":"Dagger.ModuleSource.source_root_subpath/1","doc":"The path, relative to the context directory, that contains the module's dagger.json.","ref":"Dagger.ModuleSource.html#source_root_subpath/1"},{"type":"function","title":"Dagger.ModuleSource.source_subpath/1","doc":"The path to the directory containing the module's source code, relative to the context directory.","ref":"Dagger.ModuleSource.html#source_subpath/1"},{"type":"function","title":"Dagger.ModuleSource.sync/1","doc":"Forces evaluation of the module source, including any loading into the engine and associated validation.","ref":"Dagger.ModuleSource.html#sync/1"},{"type":"type","title":"Dagger.ModuleSource.t/0","doc":"","ref":"Dagger.ModuleSource.html#t:t/0"},{"type":"function","title":"Dagger.ModuleSource.version/1","doc":"The specified version of the git repo this source points to. Only valid for git sources.","ref":"Dagger.ModuleSource.html#version/1"},{"type":"function","title":"Dagger.ModuleSource.with_client/4","doc":"Update the module source with a new client to generate.","ref":"Dagger.ModuleSource.html#with_client/4"},{"type":"function","title":"Dagger.ModuleSource.with_dependencies/2","doc":"Append the provided dependencies to the module source's dependency list.","ref":"Dagger.ModuleSource.html#with_dependencies/2"},{"type":"function","title":"Dagger.ModuleSource.with_engine_version/2","doc":"Upgrade the engine version of the module to the given value.","ref":"Dagger.ModuleSource.html#with_engine_version/2"},{"type":"function","title":"Dagger.ModuleSource.with_includes/2","doc":"Update the module source with additional include patterns for files+directories from its context that are required for building it","ref":"Dagger.ModuleSource.html#with_includes/2"},{"type":"function","title":"Dagger.ModuleSource.with_name/2","doc":"Update the module source with a new name.","ref":"Dagger.ModuleSource.html#with_name/2"},{"type":"function","title":"Dagger.ModuleSource.with_sdk/2","doc":"Update the module source with a new SDK.","ref":"Dagger.ModuleSource.html#with_sdk/2"},{"type":"function","title":"Dagger.ModuleSource.with_source_subpath/2","doc":"Update the module source with a new source subpath.","ref":"Dagger.ModuleSource.html#with_source_subpath/2"},{"type":"function","title":"Dagger.ModuleSource.with_update_dependencies/2","doc":"Update one or more module dependencies.","ref":"Dagger.ModuleSource.html#with_update_dependencies/2"},{"type":"function","title":"Dagger.ModuleSource.without_dependencies/2","doc":"Remove the provided dependencies from the module source's dependency list.","ref":"Dagger.ModuleSource.html#without_dependencies/2"},{"type":"module","title":"Dagger.ModuleSourceID","doc":"The `ModuleSourceID` scalar type represents an identifier for an object of type ModuleSource.","ref":"Dagger.ModuleSourceID.html"},{"type":"type","title":"Dagger.ModuleSourceID.t/0","doc":"","ref":"Dagger.ModuleSourceID.html#t:t/0"},{"type":"module","title":"Dagger.ModuleSourceKind","doc":"The kind of module source.","ref":"Dagger.ModuleSourceKind.html"},{"type":"function","title":"Dagger.ModuleSourceKind.dir_source/0","doc":"","ref":"Dagger.ModuleSourceKind.html#dir_source/0"},{"type":"function","title":"Dagger.ModuleSourceKind.git_source/0","doc":"","ref":"Dagger.ModuleSourceKind.html#git_source/0"},{"type":"function","title":"Dagger.ModuleSourceKind.local_source/0","doc":"","ref":"Dagger.ModuleSourceKind.html#local_source/0"},{"type":"type","title":"Dagger.ModuleSourceKind.t/0","doc":"","ref":"Dagger.ModuleSourceKind.html#t:t/0"},{"type":"module","title":"Dagger.NetworkProtocol","doc":"Transport layer network protocol associated to a port.","ref":"Dagger.NetworkProtocol.html"},{"type":"type","title":"Dagger.NetworkProtocol.t/0","doc":"","ref":"Dagger.NetworkProtocol.html#t:t/0"},{"type":"function","title":"Dagger.NetworkProtocol.tcp/0","doc":"","ref":"Dagger.NetworkProtocol.html#tcp/0"},{"type":"function","title":"Dagger.NetworkProtocol.udp/0","doc":"","ref":"Dagger.NetworkProtocol.html#udp/0"},{"type":"module","title":"Dagger.ObjectTypeDef","doc":"A definition of a custom object defined in a Module.","ref":"Dagger.ObjectTypeDef.html"},{"type":"function","title":"Dagger.ObjectTypeDef.constructor/1","doc":"The function used to construct new instances of this object, if any","ref":"Dagger.ObjectTypeDef.html#constructor/1"},{"type":"function","title":"Dagger.ObjectTypeDef.description/1","doc":"The doc string for the object, if any.","ref":"Dagger.ObjectTypeDef.html#description/1"},{"type":"function","title":"Dagger.ObjectTypeDef.fields/1","doc":"Static fields defined on this object, if any.","ref":"Dagger.ObjectTypeDef.html#fields/1"},{"type":"function","title":"Dagger.ObjectTypeDef.functions/1","doc":"Functions defined on this object, if any.","ref":"Dagger.ObjectTypeDef.html#functions/1"},{"type":"function","title":"Dagger.ObjectTypeDef.id/1","doc":"A unique identifier for this ObjectTypeDef.","ref":"Dagger.ObjectTypeDef.html#id/1"},{"type":"function","title":"Dagger.ObjectTypeDef.name/1","doc":"The name of the object.","ref":"Dagger.ObjectTypeDef.html#name/1"},{"type":"function","title":"Dagger.ObjectTypeDef.source_map/1","doc":"The location of this object declaration.","ref":"Dagger.ObjectTypeDef.html#source_map/1"},{"type":"function","title":"Dagger.ObjectTypeDef.source_module_name/1","doc":"If this ObjectTypeDef is associated with a Module, the name of the module. Unset otherwise.","ref":"Dagger.ObjectTypeDef.html#source_module_name/1"},{"type":"type","title":"Dagger.ObjectTypeDef.t/0","doc":"","ref":"Dagger.ObjectTypeDef.html#t:t/0"},{"type":"module","title":"Dagger.ObjectTypeDefID","doc":"The `ObjectTypeDefID` scalar type represents an identifier for an object of type ObjectTypeDef.","ref":"Dagger.ObjectTypeDefID.html"},{"type":"type","title":"Dagger.ObjectTypeDefID.t/0","doc":"","ref":"Dagger.ObjectTypeDefID.html#t:t/0"},{"type":"module","title":"Dagger.PipelineLabel","doc":"Key value object that represents a pipeline label.","ref":"Dagger.PipelineLabel.html"},{"type":"type","title":"Dagger.PipelineLabel.t/0","doc":"","ref":"Dagger.PipelineLabel.html#t:t/0"},{"type":"module","title":"Dagger.Platform","doc":"The platform config OS and architecture in a Container.\n\nThe format is [os]/[platform]/[version] (e.g., \"darwin/arm64/v7\", \"windows/amd64\", \"linux/arm64\").","ref":"Dagger.Platform.html"},{"type":"type","title":"Dagger.Platform.t/0","doc":"","ref":"Dagger.Platform.html#t:t/0"},{"type":"module","title":"Dagger.Port","doc":"A port exposed by a container.","ref":"Dagger.Port.html"},{"type":"function","title":"Dagger.Port.description/1","doc":"The port description.","ref":"Dagger.Port.html#description/1"},{"type":"function","title":"Dagger.Port.experimental_skip_healthcheck/1","doc":"Skip the health check when run as a service.","ref":"Dagger.Port.html#experimental_skip_healthcheck/1"},{"type":"function","title":"Dagger.Port.id/1","doc":"A unique identifier for this Port.","ref":"Dagger.Port.html#id/1"},{"type":"function","title":"Dagger.Port.port/1","doc":"The port number.","ref":"Dagger.Port.html#port/1"},{"type":"function","title":"Dagger.Port.protocol/1","doc":"The transport layer protocol.","ref":"Dagger.Port.html#protocol/1"},{"type":"type","title":"Dagger.Port.t/0","doc":"","ref":"Dagger.Port.html#t:t/0"},{"type":"module","title":"Dagger.PortForward","doc":"Port forwarding rules for tunneling network traffic.","ref":"Dagger.PortForward.html"},{"type":"type","title":"Dagger.PortForward.t/0","doc":"","ref":"Dagger.PortForward.html#t:t/0"},{"type":"module","title":"Dagger.PortID","doc":"The `PortID` scalar type represents an identifier for an object of type Port.","ref":"Dagger.PortID.html"},{"type":"type","title":"Dagger.PortID.t/0","doc":"","ref":"Dagger.PortID.html#t:t/0"},{"type":"module","title":"Dagger.ReturnType","doc":"Expected return type of an execution","ref":"Dagger.ReturnType.html"},{"type":"function","title":"Dagger.ReturnType.any/0","doc":"Any execution (exit codes 0-127)","ref":"Dagger.ReturnType.html#any/0"},{"type":"function","title":"Dagger.ReturnType.failure/0","doc":"A failed execution (exit codes 1-127)","ref":"Dagger.ReturnType.html#failure/0"},{"type":"function","title":"Dagger.ReturnType.success/0","doc":"A successful execution (exit code 0)","ref":"Dagger.ReturnType.html#success/0"},{"type":"type","title":"Dagger.ReturnType.t/0","doc":"","ref":"Dagger.ReturnType.html#t:t/0"},{"type":"module","title":"Dagger.SDKConfig","doc":"The SDK config of the module.","ref":"Dagger.SDKConfig.html"},{"type":"function","title":"Dagger.SDKConfig.id/1","doc":"A unique identifier for this SDKConfig.","ref":"Dagger.SDKConfig.html#id/1"},{"type":"function","title":"Dagger.SDKConfig.source/1","doc":"Source of the SDK. Either a name of a builtin SDK or a module source ref string pointing to the SDK's implementation.","ref":"Dagger.SDKConfig.html#source/1"},{"type":"type","title":"Dagger.SDKConfig.t/0","doc":"","ref":"Dagger.SDKConfig.html#t:t/0"},{"type":"module","title":"Dagger.SDKConfigID","doc":"The `SDKConfigID` scalar type represents an identifier for an object of type SDKConfig.","ref":"Dagger.SDKConfigID.html"},{"type":"type","title":"Dagger.SDKConfigID.t/0","doc":"","ref":"Dagger.SDKConfigID.html#t:t/0"},{"type":"module","title":"Dagger.ScalarTypeDef","doc":"A definition of a custom scalar defined in a Module.","ref":"Dagger.ScalarTypeDef.html"},{"type":"function","title":"Dagger.ScalarTypeDef.description/1","doc":"A doc string for the scalar, if any.","ref":"Dagger.ScalarTypeDef.html#description/1"},{"type":"function","title":"Dagger.ScalarTypeDef.id/1","doc":"A unique identifier for this ScalarTypeDef.","ref":"Dagger.ScalarTypeDef.html#id/1"},{"type":"function","title":"Dagger.ScalarTypeDef.name/1","doc":"The name of the scalar.","ref":"Dagger.ScalarTypeDef.html#name/1"},{"type":"function","title":"Dagger.ScalarTypeDef.source_module_name/1","doc":"If this ScalarTypeDef is associated with a Module, the name of the module. Unset otherwise.","ref":"Dagger.ScalarTypeDef.html#source_module_name/1"},{"type":"type","title":"Dagger.ScalarTypeDef.t/0","doc":"","ref":"Dagger.ScalarTypeDef.html#t:t/0"},{"type":"module","title":"Dagger.ScalarTypeDefID","doc":"The `ScalarTypeDefID` scalar type represents an identifier for an object of type ScalarTypeDef.","ref":"Dagger.ScalarTypeDefID.html"},{"type":"type","title":"Dagger.ScalarTypeDefID.t/0","doc":"","ref":"Dagger.ScalarTypeDefID.html#t:t/0"},{"type":"module","title":"Dagger.Secret","doc":"A reference to a secret value, which can be handled more safely than the value itself.","ref":"Dagger.Secret.html"},{"type":"function","title":"Dagger.Secret.id/1","doc":"A unique identifier for this Secret.","ref":"Dagger.Secret.html#id/1"},{"type":"function","title":"Dagger.Secret.name/1","doc":"The name of this secret.","ref":"Dagger.Secret.html#name/1"},{"type":"function","title":"Dagger.Secret.plaintext/1","doc":"The value of this secret.","ref":"Dagger.Secret.html#plaintext/1"},{"type":"type","title":"Dagger.Secret.t/0","doc":"","ref":"Dagger.Secret.html#t:t/0"},{"type":"function","title":"Dagger.Secret.uri/1","doc":"The URI of this secret.","ref":"Dagger.Secret.html#uri/1"},{"type":"module","title":"Dagger.SecretID","doc":"The `SecretID` scalar type represents an identifier for an object of type Secret.","ref":"Dagger.SecretID.html"},{"type":"type","title":"Dagger.SecretID.t/0","doc":"","ref":"Dagger.SecretID.html#t:t/0"},{"type":"module","title":"Dagger.Service","doc":"A content-addressed service providing TCP connectivity.","ref":"Dagger.Service.html"},{"type":"function","title":"Dagger.Service.endpoint/2","doc":"Retrieves an endpoint that clients can use to reach this container.\n\nIf no port is specified, the first exposed port is used. If none exist an error is returned.\n\nIf a scheme is specified, a URL is returned. Otherwise, a host:port pair is returned.","ref":"Dagger.Service.html#endpoint/2"},{"type":"function","title":"Dagger.Service.hostname/1","doc":"Retrieves a hostname which can be used by clients to reach this container.","ref":"Dagger.Service.html#hostname/1"},{"type":"function","title":"Dagger.Service.id/1","doc":"A unique identifier for this Service.","ref":"Dagger.Service.html#id/1"},{"type":"function","title":"Dagger.Service.ports/1","doc":"Retrieves the list of ports provided by the service.","ref":"Dagger.Service.html#ports/1"},{"type":"function","title":"Dagger.Service.start/1","doc":"Start the service and wait for its health checks to succeed.\n\nServices bound to a Container do not need to be manually started.","ref":"Dagger.Service.html#start/1"},{"type":"function","title":"Dagger.Service.stop/2","doc":"Stop the service.","ref":"Dagger.Service.html#stop/2"},{"type":"type","title":"Dagger.Service.t/0","doc":"","ref":"Dagger.Service.html#t:t/0"},{"type":"function","title":"Dagger.Service.up/2","doc":"Creates a tunnel that forwards traffic from the caller's network to this service.","ref":"Dagger.Service.html#up/2"},{"type":"function","title":"Dagger.Service.with_hostname/2","doc":"Configures a hostname which can be used by clients within the session to reach this container.","ref":"Dagger.Service.html#with_hostname/2"},{"type":"module","title":"Dagger.ServiceID","doc":"The `ServiceID` scalar type represents an identifier for an object of type Service.","ref":"Dagger.ServiceID.html"},{"type":"type","title":"Dagger.ServiceID.t/0","doc":"","ref":"Dagger.ServiceID.html#t:t/0"},{"type":"module","title":"Dagger.Socket","doc":"A Unix or TCP/IP socket that can be mounted into a container.","ref":"Dagger.Socket.html"},{"type":"function","title":"Dagger.Socket.id/1","doc":"A unique identifier for this Socket.","ref":"Dagger.Socket.html#id/1"},{"type":"type","title":"Dagger.Socket.t/0","doc":"","ref":"Dagger.Socket.html#t:t/0"},{"type":"module","title":"Dagger.SocketID","doc":"The `SocketID` scalar type represents an identifier for an object of type Socket.","ref":"Dagger.SocketID.html"},{"type":"type","title":"Dagger.SocketID.t/0","doc":"","ref":"Dagger.SocketID.html#t:t/0"},{"type":"module","title":"Dagger.SourceMap","doc":"Source location information.","ref":"Dagger.SourceMap.html"},{"type":"function","title":"Dagger.SourceMap.column/1","doc":"The column number within the line.","ref":"Dagger.SourceMap.html#column/1"},{"type":"function","title":"Dagger.SourceMap.filename/1","doc":"The filename from the module source.","ref":"Dagger.SourceMap.html#filename/1"},{"type":"function","title":"Dagger.SourceMap.id/1","doc":"A unique identifier for this SourceMap.","ref":"Dagger.SourceMap.html#id/1"},{"type":"function","title":"Dagger.SourceMap.line/1","doc":"The line number within the filename.","ref":"Dagger.SourceMap.html#line/1"},{"type":"function","title":"Dagger.SourceMap.module/1","doc":"The module dependency this was declared in.","ref":"Dagger.SourceMap.html#module/1"},{"type":"type","title":"Dagger.SourceMap.t/0","doc":"","ref":"Dagger.SourceMap.html#t:t/0"},{"type":"module","title":"Dagger.SourceMapID","doc":"The `SourceMapID` scalar type represents an identifier for an object of type SourceMap.","ref":"Dagger.SourceMapID.html"},{"type":"type","title":"Dagger.SourceMapID.t/0","doc":"","ref":"Dagger.SourceMapID.html#t:t/0"},{"type":"module","title":"Dagger.Terminal","doc":"An interactive terminal that clients can connect to.","ref":"Dagger.Terminal.html"},{"type":"function","title":"Dagger.Terminal.id/1","doc":"A unique identifier for this Terminal.","ref":"Dagger.Terminal.html#id/1"},{"type":"function","title":"Dagger.Terminal.sync/1","doc":"Forces evaluation of the pipeline in the engine.\n\nIt doesn't run the default command if no exec has been set.","ref":"Dagger.Terminal.html#sync/1"},{"type":"type","title":"Dagger.Terminal.t/0","doc":"","ref":"Dagger.Terminal.html#t:t/0"},{"type":"module","title":"Dagger.TerminalID","doc":"The `TerminalID` scalar type represents an identifier for an object of type Terminal.","ref":"Dagger.TerminalID.html"},{"type":"type","title":"Dagger.TerminalID.t/0","doc":"","ref":"Dagger.TerminalID.html#t:t/0"},{"type":"module","title":"Dagger.TypeDef","doc":"A definition of a parameter or return type in a Module.","ref":"Dagger.TypeDef.html"},{"type":"function","title":"Dagger.TypeDef.as_enum/1","doc":"If kind is ENUM, the enum-specific type definition. If kind is not ENUM, this will be null.","ref":"Dagger.TypeDef.html#as_enum/1"},{"type":"function","title":"Dagger.TypeDef.as_input/1","doc":"If kind is INPUT, the input-specific type definition. If kind is not INPUT, this will be null.","ref":"Dagger.TypeDef.html#as_input/1"},{"type":"function","title":"Dagger.TypeDef.as_interface/1","doc":"If kind is INTERFACE, the interface-specific type definition. If kind is not INTERFACE, this will be null.","ref":"Dagger.TypeDef.html#as_interface/1"},{"type":"function","title":"Dagger.TypeDef.as_list/1","doc":"If kind is LIST, the list-specific type definition. If kind is not LIST, this will be null.","ref":"Dagger.TypeDef.html#as_list/1"},{"type":"function","title":"Dagger.TypeDef.as_object/1","doc":"If kind is OBJECT, the object-specific type definition. If kind is not OBJECT, this will be null.","ref":"Dagger.TypeDef.html#as_object/1"},{"type":"function","title":"Dagger.TypeDef.as_scalar/1","doc":"If kind is SCALAR, the scalar-specific type definition. If kind is not SCALAR, this will be null.","ref":"Dagger.TypeDef.html#as_scalar/1"},{"type":"function","title":"Dagger.TypeDef.id/1","doc":"A unique identifier for this TypeDef.","ref":"Dagger.TypeDef.html#id/1"},{"type":"function","title":"Dagger.TypeDef.kind/1","doc":"The kind of type this is (e.g. primitive, list, object).","ref":"Dagger.TypeDef.html#kind/1"},{"type":"function","title":"Dagger.TypeDef.optional/1","doc":"Whether this type can be set to null. Defaults to false.","ref":"Dagger.TypeDef.html#optional/1"},{"type":"type","title":"Dagger.TypeDef.t/0","doc":"","ref":"Dagger.TypeDef.html#t:t/0"},{"type":"function","title":"Dagger.TypeDef.with_constructor/2","doc":"Adds a function for constructing a new instance of an Object TypeDef, failing if the type is not an object.","ref":"Dagger.TypeDef.html#with_constructor/2"},{"type":"function","title":"Dagger.TypeDef.with_enum/3","doc":"Returns a TypeDef of kind Enum with the provided name.\n\nNote that an enum's values may be omitted if the intent is only to refer to an enum. This is how functions are able to return their own, or any other circular reference.","ref":"Dagger.TypeDef.html#with_enum/3"},{"type":"function","title":"Dagger.TypeDef.with_enum_value/3","doc":"Adds a static value for an Enum TypeDef, failing if the type is not an enum.","ref":"Dagger.TypeDef.html#with_enum_value/3"},{"type":"function","title":"Dagger.TypeDef.with_field/4","doc":"Adds a static field for an Object TypeDef, failing if the type is not an object.","ref":"Dagger.TypeDef.html#with_field/4"},{"type":"function","title":"Dagger.TypeDef.with_function/2","doc":"Adds a function for an Object or Interface TypeDef, failing if the type is not one of those kinds.","ref":"Dagger.TypeDef.html#with_function/2"},{"type":"function","title":"Dagger.TypeDef.with_interface/3","doc":"Returns a TypeDef of kind Interface with the provided name.","ref":"Dagger.TypeDef.html#with_interface/3"},{"type":"function","title":"Dagger.TypeDef.with_kind/2","doc":"Sets the kind of the type.","ref":"Dagger.TypeDef.html#with_kind/2"},{"type":"function","title":"Dagger.TypeDef.with_list_of/2","doc":"Returns a TypeDef of kind List with the provided type for its elements.","ref":"Dagger.TypeDef.html#with_list_of/2"},{"type":"function","title":"Dagger.TypeDef.with_object/3","doc":"Returns a TypeDef of kind Object with the provided name.\n\nNote that an object's fields and functions may be omitted if the intent is only to refer to an object. This is how functions are able to return their own object, or any other circular reference.","ref":"Dagger.TypeDef.html#with_object/3"},{"type":"function","title":"Dagger.TypeDef.with_optional/2","doc":"Sets whether this type can be set to null.","ref":"Dagger.TypeDef.html#with_optional/2"},{"type":"function","title":"Dagger.TypeDef.with_scalar/3","doc":"Returns a TypeDef of kind Scalar with the provided name.","ref":"Dagger.TypeDef.html#with_scalar/3"},{"type":"module","title":"Dagger.TypeDefID","doc":"The `TypeDefID` scalar type represents an identifier for an object of type TypeDef.","ref":"Dagger.TypeDefID.html"},{"type":"type","title":"Dagger.TypeDefID.t/0","doc":"","ref":"Dagger.TypeDefID.html#t:t/0"},{"type":"module","title":"Dagger.TypeDefKind","doc":"Distinguishes the different kinds of TypeDefs.","ref":"Dagger.TypeDefKind.html"},{"type":"function","title":"Dagger.TypeDefKind.boolean_kind/0","doc":"A boolean value.","ref":"Dagger.TypeDefKind.html#boolean_kind/0"},{"type":"function","title":"Dagger.TypeDefKind.enum_kind/0","doc":"A GraphQL enum type and its values\n\nAlways paired with an EnumTypeDef.","ref":"Dagger.TypeDefKind.html#enum_kind/0"},{"type":"function","title":"Dagger.TypeDefKind.float_kind/0","doc":"A float value.","ref":"Dagger.TypeDefKind.html#float_kind/0"},{"type":"function","title":"Dagger.TypeDefKind.input_kind/0","doc":"A graphql input type, used only when representing the core API via TypeDefs.","ref":"Dagger.TypeDefKind.html#input_kind/0"},{"type":"function","title":"Dagger.TypeDefKind.integer_kind/0","doc":"An integer value.","ref":"Dagger.TypeDefKind.html#integer_kind/0"},{"type":"function","title":"Dagger.TypeDefKind.interface_kind/0","doc":"A named type of functions that can be matched+implemented by other objects+interfaces.\n\nAlways paired with an InterfaceTypeDef.","ref":"Dagger.TypeDefKind.html#interface_kind/0"},{"type":"function","title":"Dagger.TypeDefKind.list_kind/0","doc":"A list of values all having the same type.\n\nAlways paired with a ListTypeDef.","ref":"Dagger.TypeDefKind.html#list_kind/0"},{"type":"function","title":"Dagger.TypeDefKind.object_kind/0","doc":"A named type defined in the GraphQL schema, with fields and functions.\n\nAlways paired with an ObjectTypeDef.","ref":"Dagger.TypeDefKind.html#object_kind/0"},{"type":"function","title":"Dagger.TypeDefKind.scalar_kind/0","doc":"A scalar value of any basic kind.","ref":"Dagger.TypeDefKind.html#scalar_kind/0"},{"type":"function","title":"Dagger.TypeDefKind.string_kind/0","doc":"A string value.","ref":"Dagger.TypeDefKind.html#string_kind/0"},{"type":"type","title":"Dagger.TypeDefKind.t/0","doc":"","ref":"Dagger.TypeDefKind.html#t:t/0"},{"type":"function","title":"Dagger.TypeDefKind.void_kind/0","doc":"A special kind used to signify that no value is returned.\n\nThis is used for functions that have no return value. The outer TypeDef specifying this Kind is always Optional, as the Void is never actually represented.","ref":"Dagger.TypeDefKind.html#void_kind/0"},{"type":"module","title":"Dagger.Void","doc":"The absence of a value.\n\nA Null Void is used as a placeholder for resolvers that do not return anything.","ref":"Dagger.Void.html"},{"type":"type","title":"Dagger.Void.t/0","doc":"","ref":"Dagger.Void.html#t:t/0"},{"type":"task","title":"mix dagger.entrypoint.invoke","doc":"Main entrypoint for invoking a Dagger Module.\n\nNOTE: This task can run only inside Dagger Elixir runtime.","ref":"Mix.Tasks.Dagger.Entrypoint.Invoke.html"},{"type":"task","title":"Arguments - mix dagger.entrypoint.invoke","doc":"- `module` - A main module to invoke. (e.g. `Potato`)","ref":"Mix.Tasks.Dagger.Entrypoint.Invoke.html#module-arguments"},{"type":"function","title":"Mix.Tasks.Dagger.Entrypoint.Invoke.run/1","doc":"","ref":"Mix.Tasks.Dagger.Entrypoint.Invoke.html#run/1"},{"type":"exception","title":"Dagger.Core.ExecError","doc":"API error from an exec operation.","ref":"Dagger.Core.ExecError.html"},{"type":"function","title":"Dagger.Core.ExecError.from_map/1","doc":"","ref":"Dagger.Core.ExecError.html#from_map/1"},{"type":"function","title":"Dagger.Core.ExecError.with_original_error/2","doc":"","ref":"Dagger.Core.ExecError.html#with_original_error/2"},{"type":"exception","title":"Dagger.Core.GraphQL.Response.Error","doc":"","ref":"Dagger.Core.GraphQL.Response.Error.html"},{"type":"function","title":"Dagger.Core.GraphQL.Response.Error.from_map/1","doc":"","ref":"Dagger.Core.GraphQL.Response.Error.html#from_map/1"},{"type":"exception","title":"Dagger.Mod.TypeMismatchError","doc":"An error raise when the value is incompatible with type.","ref":"Dagger.Mod.TypeMismatchError.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}